<?php
require_once 'config/config.php';
require_once 'models/TipoInspeccion.php';
require_once 'models/SeccionInspeccion.php';
require_once 'models/ElementoInspeccion.php';

requireLogin();

// Solo administradores pueden acceder
if (!isAdmin()) {
    header('Location: dashboard.php');
    exit();
}

$tipo_id = $_GET['tipo_id'] ?? null;
if (!$tipo_id) {
    header('Location: admin_inspecciones.php');
    exit();
}

$tipoInspeccion = new TipoInspeccion();
$seccionInspeccion = new SeccionInspeccion();
$elementoInspeccion = new ElementoInspeccion();

$tipo = $tipoInspeccion->getById($tipo_id);
if (!$tipo) {
    header('Location: admin_inspecciones.php');
    exit();
}

$secciones = $seccionInspeccion->getConElementos($tipo_id);

$message = '';
$message_type = '';

// Procesar acciones
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    try {
        if (isset($_POST['action'])) {
            switch ($_POST['action']) {
                case 'create_seccion':
                    $data = [
                        'tipo_inspeccion_id' => $tipo_id,
                        'nombre' => cleanInput($_POST['nombre']),
                        'descripcion' => cleanInput($_POST['descripcion']),
                        'orden' => (int)($_POST['orden'] ?? 0),
                        'activo' => isset($_POST['activo']) ? 1 : 0
                    ];
                    
                    if ($seccionInspeccion->create($data)) {
                        $message = 'Sección creada exitosamente';
                        $message_type = 'success';
                    } else {
                        $message = 'Error al crear la sección';
                        $message_type = 'danger';
                    }
                    break;
                    
                case 'create_elemento':
                    $data = [
                        'seccion_id' => (int)$_POST['seccion_id'],
                        'descripcion' => cleanInput($_POST['descripcion']),
                        'orden' => (int)($_POST['orden'] ?? 0),
                        'obligatorio' => isset($_POST['obligatorio']) ? 1 : 0,
                        'activo' => isset($_POST['activo']) ? 1 : 0,
                        'tipo_respuesta' => cleanInput($_POST['tipo_respuesta'])
                    ];
                    
                    if ($elementoInspeccion->create($data)) {
                        $message = 'Elemento creado exitosamente';
                        $message_type = 'success';
                    } else {
                        $message = 'Error al crear el elemento';
                        $message_type = 'danger';
                    }
                    break;
                    
                case 'update_seccion':
                    $data = [
                        'nombre' => cleanInput($_POST['nombre']),
                        'descripcion' => cleanInput($_POST['descripcion']),
                        'orden' => (int)($_POST['orden'] ?? 0),
                        'activo' => isset($_POST['activo']) ? 1 : 0
                    ];
                    
                    if ($seccionInspeccion->update($_POST['id'], $data)) {
                        $message = 'Sección actualizada exitosamente';
                        $message_type = 'success';
                    } else {
                        $message = 'Error al actualizar la sección';
                        $message_type = 'danger';
                    }
                    break;
                    
                case 'update_elemento':
                    $data = [
                        'descripcion' => cleanInput($_POST['descripcion']),
                        'orden' => (int)($_POST['orden'] ?? 0),
                        'obligatorio' => isset($_POST['obligatorio']) ? 1 : 0,
                        'activo' => isset($_POST['activo']) ? 1 : 0,
                        'tipo_respuesta' => cleanInput($_POST['tipo_respuesta'])
                    ];
                    
                    if ($elementoInspeccion->update($_POST['id'], $data)) {
                        $message = 'Elemento actualizado exitosamente';
                        $message_type = 'success';
                    } else {
                        $message = 'Error al actualizar el elemento';
                        $message_type = 'danger';
                    }
                    break;
                    
                case 'delete_seccion':
                    if ($seccionInspeccion->delete($_POST['id'])) {
                        $message = 'Sección eliminada exitosamente';
                        $message_type = 'success';
                    } else {
                        $message = 'Error al eliminar la sección';
                        $message_type = 'danger';
                    }
                    break;
                    
                case 'delete_elemento':
                    if ($elementoInspeccion->delete($_POST['id'])) {
                        $message = 'Elemento eliminado exitosamente';
                        $message_type = 'success';
                    } else {
                        $message = 'Error al eliminar el elemento';
                        $message_type = 'danger';
                    }
                    break;
            }
        }
        
        // Recargar datos
        $secciones = $seccionInspeccion->getConElementos($tipo_id);
        
    } catch (Exception $e) {
        $message = 'Error: ' . $e->getMessage();
        $message_type = 'danger';
    }
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Gestionar Elementos - <?php echo htmlspecialchars($tipo['nombre']); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        :root {
            --primary: #0070f3;
            --success: #00d084;
            --warning: #f5a623;
            --danger: #e00;
            --gray-50: #fafafa;
            --gray-100: #f4f4f5;
            --gray-200: #e4e4e7;
            --gray-300: #d4d4d8;
            --gray-600: #52525b;
            --gray-700: #3f3f46;
            --gray-900: #18181b;
        }

        body {
            font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', sans-serif;
            background-color: var(--gray-50);
            color: var(--gray-900);
        }

        .header {
            background: white;
            border-bottom: 1px solid var(--gray-200);
            padding: 1rem 0;
            box-shadow: 0 1px 3px rgba(0,0,0,0.1);
        }

        .main-container {
            max-width: 1400px;
            margin: 0 auto;
            padding: 2rem 1rem;
        }

        .card {
            background: white;
            border: 1px solid var(--gray-200);
            border-radius: 12px;
            box-shadow: 0 1px 3px rgba(0,0,0,0.1);
            margin-bottom: 2rem;
        }

        .card-header {
            padding: 1.5rem;
            border-bottom: 1px solid var(--gray-200);
            background-color: var(--gray-50);
        }

        .card-body {
            padding: 1.5rem;
        }

        .seccion-card {
            border-left: 4px solid var(--primary);
            margin-bottom: 1.5rem;
        }

        .elemento-item {
            background: var(--gray-50);
            border: 1px solid var(--gray-200);
            border-radius: 8px;
            padding: 1rem;
            margin-bottom: 0.75rem;
        }

        .btn {
            padding: 0.5rem 1rem;
            border: none;
            border-radius: 6px;
            font-weight: 500;
            cursor: pointer;
            transition: all 0.2s;
            text-decoration: none;
            display: inline-flex;
            align-items: center;
            gap: 0.5rem;
        }

        .btn-primary {
            background: var(--primary);
            color: white;
        }

        .btn-success {
            background: var(--success);
            color: white;
        }

        .btn-warning {
            background: var(--warning);
            color: white;
        }

        .btn-danger {
            background: var(--danger);
            color: white;
        }

        .btn-outline-primary {
            border: 1px solid var(--primary);
            color: var(--primary);
            background: transparent;
        }

        .btn-outline-secondary {
            border: 1px solid var(--gray-300);
            color: var(--gray-700);
            background: transparent;
        }

        .btn-sm {
            padding: 0.375rem 0.75rem;
            font-size: 0.875rem;
        }

        .status-badge {
            padding: 0.25rem 0.75rem;
            border-radius: 12px;
            font-size: 0.75rem;
            font-weight: 600;
            text-transform: uppercase;
        }

        .status-active {
            background: rgba(0, 208, 132, 0.1);
            color: var(--success);
        }

        .status-inactive {
            background: var(--gray-100);
            color: var(--gray-600);
        }

        .status-required {
            background: rgba(224, 0, 0, 0.1);
            color: var(--danger);
        }

        .status-optional {
            background: rgba(245, 166, 35, 0.1);
            color: var(--warning);
        }

        .tipo-respuesta-badge {
            padding: 0.25rem 0.5rem;
            border-radius: 6px;
            font-size: 0.75rem;
            font-weight: 500;
            background: var(--gray-100);
            color: var(--gray-700);
        }
    </style>
</head>
<body>
    <!-- Header -->
    <header class="header">
        <div class="container-fluid">
            <div class="d-flex justify-content-between align-items-center">
                <div>
                    <a href="dashboard.php" class="text-decoration-none text-dark fw-bold">
                        <i class="fas fa-fire-extinguisher me-2"></i>
                        <?php echo APP_NAME; ?>
                    </a>
                    <span class="text-muted mx-2">/</span>
                    <a href="admin_inspecciones.php" class="text-decoration-none text-muted">Administrar Inspecciones</a>
                    <span class="text-muted mx-2">/</span>
                    <span class="fw-bold"><?php echo htmlspecialchars($tipo['nombre']); ?></span>
                </div>
                <div>
                    <a href="admin_inspecciones.php" class="btn btn-outline-secondary btn-sm">
                        <i class="fas fa-arrow-left"></i> Volver
                    </a>
                </div>
            </div>
        </div>
    </header>

    <div class="main-container">
        <!-- Alert -->
        <?php if ($message): ?>
            <div class="alert alert-<?php echo $message_type; ?> alert-dismissible fade show" role="alert">
                <i class="fas fa-<?php echo $message_type === 'success' ? 'check-circle' : 'exclamation-triangle'; ?> me-2"></i>
                <?php echo $message; ?>
                <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
            </div>
        <?php endif; ?>

        <!-- Page Header -->
        <div class="d-flex justify-content-between align-items-center mb-4">
            <div>
                <h1 class="h3 mb-1">Gestionar Elementos</h1>
                <p class="text-muted mb-0">
                    <strong><?php echo htmlspecialchars($tipo['nombre']); ?></strong> - 
                    Configura las secciones y preguntas de este tipo de inspección
                </p>
            </div>
            <button type="button" class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#createSeccionModal">
                <i class="fas fa-plus"></i> Nueva Sección
            </button>
        </div>

        <!-- Secciones -->
        <?php if (empty($secciones)): ?>
            <div class="card">
                <div class="card-body text-center py-5">
                    <i class="fas fa-layer-group fa-4x text-muted mb-3"></i>
                    <h5 class="text-muted">No hay secciones configuradas</h5>
                    <p class="text-muted">Crea la primera sección para organizar las preguntas de inspección</p>
                    <button type="button" class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#createSeccionModal">
                        <i class="fas fa-plus me-2"></i>Crear Primera Sección
                    </button>
                </div>
            </div>
        <?php else: ?>
            <?php foreach ($secciones as $seccion): ?>
                <div class="card seccion-card">
                    <div class="card-header">
                        <div class="d-flex justify-content-between align-items-center">
                            <div>
                                <h5 class="mb-1">
                                    <i class="fas fa-layer-group me-2"></i>
                                    <?php echo htmlspecialchars($seccion['nombre']); ?>
                                </h5>
                                <p class="text-muted mb-0">
                                    <?php echo htmlspecialchars($seccion['descripcion'] ?? 'Sin descripción'); ?>
                                </p>
                                <div class="mt-2">
                                    <span class="status-badge <?php echo $seccion['activo'] ? 'status-active' : 'status-inactive'; ?>">
                                        <?php echo $seccion['activo'] ? 'Activa' : 'Inactiva'; ?>
                                    </span>
                                    <span class="ms-2 text-muted">
                                        <i class="fas fa-list me-1"></i>
                                        <?php echo $seccion['elementos_activos']; ?>/<?php echo $seccion['total_elementos']; ?> elementos
                                    </span>
                                </div>
                            </div>
                            <div class="btn-group">
                                <button type="button" class="btn btn-sm btn-outline-primary" 
                                        onclick="editarSeccion(<?php echo htmlspecialchars(json_encode($seccion)); ?>)">
                                    <i class="fas fa-edit"></i>
                                </button>
                                <button type="button" class="btn btn-sm btn-outline-success" 
                                        onclick="crearElemento(<?php echo $seccion['id']; ?>, '<?php echo htmlspecialchars($seccion['nombre']); ?>')">
                                    <i class="fas fa-plus"></i> Elemento
                                </button>
                                <button type="button" class="btn btn-sm btn-outline-danger" 
                                        onclick="eliminarSeccion(<?php echo $seccion['id']; ?>, '<?php echo htmlspecialchars($seccion['nombre']); ?>')">
                                    <i class="fas fa-trash"></i>
                                </button>
                            </div>
                        </div>
                    </div>
                    
                    <div class="card-body">
                        <?php
                        $elementos = $elementoInspeccion->getBySeccion($seccion['id']);
                        if (empty($elementos)):
                        ?>
                            <div class="text-center py-3">
                                <i class="fas fa-question-circle fa-2x text-muted mb-2"></i>
                                <p class="text-muted mb-2">No hay elementos en esta sección</p>
                                <button type="button" class="btn btn-sm btn-outline-primary" 
                                        onclick="crearElemento(<?php echo $seccion['id']; ?>, '<?php echo htmlspecialchars($seccion['nombre']); ?>')">
                                    <i class="fas fa-plus me-1"></i>Agregar Primer Elemento
                                </button>
                            </div>
                        <?php else: ?>
                            <?php foreach ($elementos as $elemento): ?>
                                <div class="elemento-item">
                                    <div class="d-flex justify-content-between align-items-start">
                                        <div class="flex-grow-1">
                                            <div class="fw-bold mb-1">
                                                <?php echo htmlspecialchars($elemento['descripcion']); ?>
                                            </div>
                                            <div class="d-flex gap-2 flex-wrap">
                                                <span class="status-badge <?php echo $elemento['activo'] ? 'status-active' : 'status-inactive'; ?>">
                                                    <?php echo $elemento['activo'] ? 'Activo' : 'Inactivo'; ?>
                                                </span>
                                                <span class="status-badge <?php echo $elemento['obligatorio'] ? 'status-required' : 'status-optional'; ?>">
                                                    <?php echo $elemento['obligatorio'] ? 'Obligatorio' : 'Opcional'; ?>
                                                </span>
                                                <span class="tipo-respuesta-badge">
                                                    <?php 
                                                    $tipos_respuesta = [
                                                        'si_no_nc' => 'Sí/No/N/C',
                                                        'si_no' => 'Sí/No',
                                                        'texto' => 'Texto',
                                                        'numero' => 'Número'
                                                    ];
                                                    echo $tipos_respuesta[$elemento['tipo_respuesta']] ?? $elemento['tipo_respuesta'];
                                                    ?>
                                                </span>
                                            </div>
                                        </div>
                                        <div class="btn-group">
                                            <button type="button" class="btn btn-sm btn-outline-primary" 
                                                    onclick="editarElemento(<?php echo htmlspecialchars(json_encode($elemento)); ?>)">
                                                <i class="fas fa-edit"></i>
                                            </button>
                                            <button type="button" class="btn btn-sm btn-outline-danger" 
                                                    onclick="eliminarElemento(<?php echo $elemento['id']; ?>, '<?php echo htmlspecialchars($elemento['descripcion']); ?>')">
                                                <i class="fas fa-trash"></i>
                                            </button>
                                        </div>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </div>
                </div>
            <?php endforeach; ?>
        <?php endif; ?>
    </div>

    <!-- Modales aquí... -->
    <!-- Create Section Modal -->
<div class="modal fade" id="createSeccionModal" tabindex="-1">
    <div class="modal-dialog">
        <div class="modal-content">
            <form method="POST">
                <div class="modal-header">
                    <h5 class="modal-title">
                        <i class="fas fa-plus me-2"></i>Nueva Sección
                    </h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <input type="hidden" name="action" value="create_seccion">
                    
                    <div class="mb-3">
                        <label class="form-label">Nombre *</label>
                        <input type="text" class="form-control" name="nombre" required 
                               placeholder="Ej: Inspección Visual, Pruebas Funcionales...">
                    </div>
                    
                    <div class="mb-3">
                        <label class="form-label">Descripción</label>
                        <textarea class="form-control" name="descripcion" rows="3" 
                                  placeholder="Descripción de la sección..."></textarea>
                    </div>
                    
                    <div class="mb-3">
                        <label class="form-label">Orden</label>
                        <input type="number" class="form-control" name="orden" value="<?php echo count($secciones) + 1; ?>" min="1">
                    </div>
                    
                    <div class="form-check">
                        <input class="form-check-input" type="checkbox" name="activo" id="activo_seccion" checked>
                        <label class="form-check-label" for="activo_seccion">
                            Sección activa
                        </label>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancelar</button>
                    <button type="submit" class="btn btn-success">
                        <i class="fas fa-save me-2"></i>Crear Sección
                    </button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Edit Section Modal -->
<div class="modal fade" id="editSeccionModal" tabindex="-1">
    <div class="modal-dialog">
        <div class="modal-content">
            <form method="POST">
                <div class="modal-header">
                    <h5 class="modal-title">
                        <i class="fas fa-edit me-2"></i>Editar Sección
                    </h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <input type="hidden" name="action" value="update_seccion">
                    <input type="hidden" name="id" id="edit_seccion_id">
                    
                    <div class="mb-3">
                        <label class="form-label">Nombre *</label>
                        <input type="text" class="form-control" name="nombre" id="edit_seccion_nombre" required>
                    </div>
                    
                    <div class="mb-3">
                        <label class="form-label">Descripción</label>
                        <textarea class="form-control" name="descripcion" id="edit_seccion_descripcion" rows="3"></textarea>
                    </div>
                    
                    <div class="mb-3">
                        <label class="form-label">Orden</label>
                        <input type="number" class="form-control" name="orden" id="edit_seccion_orden" min="1">
                    </div>
                    
                    <div class="form-check">
                        <input class="form-check-input" type="checkbox" name="activo" id="edit_seccion_activo">
                        <label class="form-check-label" for="edit_seccion_activo">
                            Sección activa
                        </label>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancelar</button>
                    <button type="submit" class="btn btn-primary">
                        <i class="fas fa-save me-2"></i>Actualizar
                    </button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Create Element Modal -->
<div class="modal fade" id="createElementoModal" tabindex="-1">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">
            <form method="POST">
                <div class="modal-header">
                    <h5 class="modal-title">
                        <i class="fas fa-plus me-2"></i>Nuevo Elemento
                    </h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <input type="hidden" name="action" value="create_elemento">
                    <input type="hidden" name="seccion_id" id="create_seccion_id">
                    
                    <div class="mb-3">
                        <label class="form-label">Sección</label>
                        <input type="text" class="form-control" id="create_seccion_nombre_display" readonly>
                    </div>
                    
                    <div class="mb-3">
                        <label class="form-label">Pregunta/Descripción *</label>
                        <textarea class="form-control" name="descripcion" rows="3" required 
                                  placeholder="Ej: ¿El extintor está en su ubicación designada?"></textarea>
                    </div>
                    
                    <div class="row">
                        <div class="col-md-6 mb-3">
                            <label class="form-label">Tipo de Respuesta</label>
                            <select class="form-control" name="tipo_respuesta" required>
                                <option value="si_no_nc">Sí / No / N/C</option>
                                <option value="si_no">Sí / No</option>
                                <option value="texto">Texto Libre</option>
                                <option value="numero">Número</option>
                            </select>
                        </div>
                        <div class="col-md-6 mb-3">
                            <label class="form-label">Orden</label>
                            <input type="number" class="form-control" name="orden" value="1" min="1">
                        </div>
                    </div>
                    
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-check">
                                <input class="form-check-input" type="checkbox" name="obligatorio" id="obligatorio_create" checked>
                                <label class="form-check-label" for="obligatorio_create">
                                    Campo obligatorio
                                </label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-check">
                                <input class="form-check-input" type="checkbox" name="activo" id="activo_create" checked>
                                <label class="form-check-label" for="activo_create">
                                    Elemento activo
                                </label>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancelar</button>
                    <button type="submit" class="btn btn-primary">
                        <i class="fas fa-save me-2"></i>Crear Elemento
                    </button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Edit Element Modal -->
<div class="modal fade" id="editElementoModal" tabindex="-1">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">
            <form method="POST">
                <div class="modal-header">
                    <h5 class="modal-title">
                        <i class="fas fa-edit me-2"></i>Editar Elemento
                    </h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <input type="hidden" name="action" value="update_elemento">
                    <input type="hidden" name="id" id="edit_elemento_id">
                    
                    <div class="mb-3">
                        <label class="form-label">Pregunta/Descripción *</label>
                        <textarea class="form-control" name="descripcion" id="edit_descripcion" rows="3" required></textarea>
                    </div>
                    
                    <div class="row">
                        <div class="col-md-6 mb-3">
                            <label class="form-label">Tipo de Respuesta</label>
                            <select class="form-control" name="tipo_respuesta" id="edit_tipo_respuesta" required>
                                <option value="si_no_nc">Sí / No / N/C</option>
                                <option value="si_no">Sí / No</option>
                                <option value="texto">Texto Libre</option>
                                <option value="numero">Número</option>
                            </select>
                        </div>
                        <div class="col-md-6 mb-3">
                            <label class="form-label">Orden</label>
                            <input type="number" class="form-control" name="orden" id="edit_orden" min="1">
                        </div>
                    </div>
                    
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-check">
                                <input class="form-check-input" type="checkbox" name="obligatorio" id="edit_obligatorio">
                                <label class="form-check-label" for="edit_obligatorio">
                                    Campo obligatorio
                                </label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-check">
                                <input class="form-check-input" type="checkbox" name="activo" id="edit_activo">
                                <label class="form-check-label" for="edit_activo">
                                    Elemento activo
                                </label>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancelar</button>
                    <button type="submit" class="btn btn-primary">
                        <i class="fas fa-save me-2"></i>Actualizar
                    </button>
                </div>
            </form>
        </div>
    </div>
</div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        function editarSeccion(seccion) {
            document.getElementById('edit_seccion_id').value = seccion.id;
            document.getElementById('edit_seccion_nombre').value = seccion.nombre;
            document.getElementById('edit_seccion_descripcion').value = seccion.descripcion || '';
            document.getElementById('edit_seccion_orden').value = seccion.orden;
            document.getElementById('edit_seccion_activo').checked = seccion.activo == 1;
            
            new bootstrap.Modal(document.getElementById('editSeccionModal')).show();
        }

        function crearElemento(seccionId, seccionNombre) {
            document.getElementById('create_seccion_id').value = seccionId;
            document.getElementById('create_seccion_nombre_display').value = seccionNombre;
            new bootstrap.Modal(document.getElementById('createElementoModal')).show();
        }

        function editarElemento(elemento) {
            document.getElementById('edit_elemento_id').value = elemento.id;
            document.getElementById('edit_descripcion').value = elemento.descripcion;
            document.getElementById('edit_tipo_respuesta').value = elemento.tipo_respuesta;
            document.getElementById('edit_orden').value = elemento.orden;
            document.getElementById('edit_obligatorio').checked = elemento.obligatorio == 1;
            document.getElementById('edit_activo').checked = elemento.activo == 1;
            
            new bootstrap.Modal(document.getElementById('editElementoModal')).show();
        }

        function eliminarSeccion(id, nombre) {
            if (confirm(`¿Estás seguro de eliminar la sección "${nombre}"? Esto eliminará también todos sus elementos.`)) {
                const form = document.createElement('form');
                form.method = 'POST';
                form.innerHTML = `
                    <input type="hidden" name="action" value="delete_seccion">
                    <input type="hidden" name="id" value="${id}">
                `;
                document.body.appendChild(form);
                form.submit();
            }
        }

        function eliminarElemento(id, descripcion) {
            if (confirm(`¿Estás seguro de eliminar el elemento "${descripcion}"?`)) {
                const form = document.createElement('form');
                form.method = 'POST';
                form.innerHTML = `
                    <input type="hidden" name="action" value="delete_elemento">
                    <input type="hidden" name="id" value="${id}">
                `;
                document.body.appendChild(form);
                form.submit();
            }
        }
    </script>
</body>
</html>
