<?php
require_once 'config/config.php';
require_once 'models/Inspeccion.php';

requireLogin();

echo "<h2>🔧 Corrección Automática de Estados</h2>";

try {
    $database = new Database();
    $conn = $database->getConnection();
    
    // Obtener inspecciones que tienen respuestas pero están como borrador
    $query = "SELECT i.id, i.numero_contrato, i.estado, 
                     COUNT(r.id) as total_respuestas
              FROM inspecciones i
              LEFT JOIN respuestas_inspeccion r ON i.id = r.inspeccion_id
              WHERE i.estado = 'borrador'
              GROUP BY i.id
              HAVING total_respuestas > 0";
    
    $stmt = $conn->prepare($query);
    $stmt->execute();
    $inspecciones_a_corregir = $stmt->fetchAll();
    
    if (empty($inspecciones_a_corregir)) {
        echo "<p>✅ No hay inspecciones que necesiten corrección.</p>";
    } else {
        echo "<h3>📋 Inspecciones que se corregirán:</h3>";
        echo "<table border='1' style='border-collapse: collapse; margin: 10px 0;'>";
        echo "<tr><th>ID</th><th>Contrato</th><th>Estado Actual</th><th>Respuestas</th><th>Nuevo Estado</th></tr>";
        
        foreach ($inspecciones_a_corregir as $insp) {
            echo "<tr>";
            echo "<td>" . $insp['id'] . "</td>";
            echo "<td>" . ($insp['numero_contrato'] ?: 'Sin contrato') . "</td>";
            echo "<td style='color: orange;'>" . $insp['estado'] . "</td>";
            echo "<td>" . $insp['total_respuestas'] . "</td>";
            echo "<td style='color: green; font-weight: bold;'>completada</td>";
            echo "</tr>";
        }
        echo "</table>";
        
        // Actualizar los estados
        $update_query = "UPDATE inspecciones 
                        SET estado = 'completada' 
                        WHERE id IN (
                            SELECT inspeccion_id FROM respuestas_inspeccion 
                            GROUP BY inspeccion_id 
                            HAVING COUNT(*) > 0
                        ) AND estado = 'borrador'";
        
        $update_stmt = $conn->prepare($update_query);
        if ($update_stmt->execute()) {
            $affected = $update_stmt->rowCount();
            echo "<p style='color: green; font-weight: bold;'>✅ Se actualizaron $affected inspecciones a estado 'completada'.</p>";
        } else {
            echo "<p style='color: red;'>❌ Error al actualizar los estados.</p>";
        }
    }
    
    // Mostrar estado final
    echo "<h3>📊 Estado Final de Todas las Inspecciones:</h3>";
    $final_query = "SELECT i.id, i.numero_contrato, i.estado, i.fecha_inspeccion,
                           COUNT(r.id) as total_respuestas
                    FROM inspecciones i
                    LEFT JOIN respuestas_inspeccion r ON i.id = r.inspeccion_id
                    GROUP BY i.id
                    ORDER BY i.id DESC";
    
    $final_stmt = $conn->prepare($final_query);
    $final_stmt->execute();
    $todas_inspecciones = $final_stmt->fetchAll();
    
    echo "<table border='1' style='border-collapse: collapse; margin: 10px 0;'>";
    echo "<tr><th>ID</th><th>Contrato</th><th>Estado</th><th>Fecha</th><th>Respuestas</th></tr>";
    
    foreach ($todas_inspecciones as $insp) {
        $estado_color = '';
        switch ($insp['estado']) {
            case 'completada':
                $estado_color = 'color: green; font-weight: bold;';
                break;
            case 'borrador':
                $estado_color = 'color: orange; font-weight: bold;';
                break;
        }
        
        echo "<tr>";
        echo "<td>" . $insp['id'] . "</td>";
        echo "<td>" . ($insp['numero_contrato'] ?: 'Sin contrato') . "</td>";
        echo "<td style='$estado_color'>" . $insp['estado'] . "</td>";
        echo "<td>" . $insp['fecha_inspeccion'] . "</td>";
        echo "<td>" . $insp['total_respuestas'] . "</td>";
        echo "</tr>";
    }
    echo "</table>";
    
    echo "<p>🔗 <a href='inspecciones.php'>Ver Inspecciones</a> | <a href='nueva_inspeccion.php'>Nueva Inspección</a></p>";
    
} catch (Exception $e) {
    echo "<p style='color: red;'>❌ Error: " . $e->getMessage() . "</p>";
}
?>

<style>
    body { font-family: Arial, sans-serif; margin: 20px; }
    table { width: 100%; }
    th, td { padding: 8px; text-align: left; }
    th { background-color: #f2f2f2; }
    h2, h3 { color: #333; }
</style>
