<?php
// Corregir la ruta de inclusión
require_once 'config/database.php';

echo "<h2>🔍 Diagnóstico Completo del Sistema de Equipos</h2>";

try {
    // 1. Verificar conexión
    echo "<h3>1. ✅ Conexión a Base de Datos</h3>";
    $database = new Database();
    $db = $database->getConnection();
    echo "<p style='color: green;'>✅ Conexión exitosa</p>";
    
    // 2. Verificar parámetros URL
    echo "<h3>2. 📋 Parámetros Recibidos</h3>";
    echo "<div style='background: #f8f9fa; padding: 1rem; border-radius: 8px; font-family: monospace;'>";
    echo "GET paso: " . ($_GET['paso'] ?? 'NO DEFINIDO') . "<br>";
    echo "GET inmueble: " . ($_GET['inmueble'] ?? 'NO DEFINIDO') . "<br>";
    echo "GET tipo: " . ($_GET['tipo'] ?? 'NO DEFINIDO') . "<br>";
    echo "</div>";
    
    // 3. Verificar inmuebles
    echo "<h3>3. 🏢 Inmuebles Disponibles</h3>";
    $query = "SELECT * FROM inmuebles";
    $stmt = $db->prepare($query);
    $stmt->execute();
    $inmuebles = $stmt->fetchAll();
    
    if (empty($inmuebles)) {
        echo "<p style='color: red;'>❌ No hay inmuebles registrados</p>";
    } else {
        echo "<table border='1' style='border-collapse: collapse; width: 100%;'>";
        echo "<tr style='background: #f0f0f0;'><th>ID</th><th>Nombre</th><th>Dirección</th></tr>";
        foreach ($inmuebles as $inm) {
            echo "<tr>";
            echo "<td>" . $inm['id'] . "</td>";
            echo "<td>" . htmlspecialchars($inm['nombre']) . "</td>";
            echo "<td>" . htmlspecialchars($inm['direccion']) . "</td>";
            echo "</tr>";
        }
        echo "</table>";
    }
    
    // 4. Verificar tipos de inspección
    echo "<h3>4. 🔧 Tipos de Inspección</h3>";
    $query = "SELECT * FROM tipos_inspeccion WHERE activo = 1";
    $stmt = $db->prepare($query);
    $stmt->execute();
    $tipos = $stmt->fetchAll();
    
    if (empty($tipos)) {
        echo "<p style='color: red;'>❌ No hay tipos de inspección activos</p>";
    } else {
        echo "<table border='1' style='border-collapse: collapse; width: 100%;'>";
        echo "<tr style='background: #f0f0f0;'><th>ID</th><th>Nombre</th><th>Descripción</th></tr>";
        foreach ($tipos as $tipo) {
            echo "<tr>";
            echo "<td>" . $tipo['id'] . "</td>";
            echo "<td>" . htmlspecialchars($tipo['nombre']) . "</td>";
            echo "<td>" . htmlspecialchars($tipo['descripcion']) . "</td>";
            echo "</tr>";
        }
        echo "</table>";
    }
    
    // 5. Verificar equipos
    echo "<h3>5. 📦 Equipos Registrados</h3>";
    $query = "SELECT e.*, i.nombre as inmueble_nombre, t.nombre as tipo_nombre 
              FROM equipos e 
              LEFT JOIN inmuebles i ON e.inmueble_id = i.id 
              LEFT JOIN tipos_inspeccion t ON e.tipo_inspeccion_id = t.id";
    $stmt = $db->prepare($query);
    $stmt->execute();
    $equipos = $stmt->fetchAll();
    
    if (empty($equipos)) {
        echo "<p style='color: red;'>❌ No hay equipos registrados</p>";
        echo "<p><a href='gestionar_equipos.php' style='background: #28a745; color: white; padding: 0.5rem 1rem; text-decoration: none; border-radius: 4px;'>Registrar Equipos</a></p>";
    } else {
        echo "<table border='1' style='border-collapse: collapse; width: 100%;'>";
        echo "<tr style='background: #f0f0f0;'><th>ID</th><th>Código</th><th>Inmueble</th><th>Tipo</th><th>Ubicación</th><th>Estado</th></tr>";
        foreach ($equipos as $eq) {
            echo "<tr>";
            echo "<td>" . $eq['id'] . "</td>";
            echo "<td><strong>" . htmlspecialchars($eq['codigo_equipo']) . "</strong></td>";
            echo "<td>" . htmlspecialchars($eq['inmueble_nombre']) . "</td>";
            echo "<td>" . htmlspecialchars($eq['tipo_nombre']) . "</td>";
            echo "<td>" . htmlspecialchars($eq['ubicacion']) . "</td>";
            echo "<td>" . ucfirst($eq['estado_equipo']) . "</td>";
            echo "</tr>";
        }
        echo "</table>";
    }
    
    // 6. Verificar elementos de inspección
    echo "<h3>6. 📝 Elementos de Inspección</h3>";
    $query = "SELECT e.*, s.nombre as seccion_nombre, t.nombre as tipo_nombre
              FROM elementos_inspeccion e
              LEFT JOIN secciones_inspeccion s ON e.seccion_id = s.id
              LEFT JOIN tipos_inspeccion t ON s.tipo_inspeccion_id = t.id
              ORDER BY t.nombre, s.orden, e.orden";
    $stmt = $db->prepare($query);
    $stmt->execute();
    $elementos = $stmt->fetchAll();
    
    if (empty($elementos)) {
        echo "<p style='color: red;'>❌ No hay elementos de inspección configurados</p>";
    } else {
        echo "<p style='color: green;'>✅ " . count($elementos) . " elementos encontrados</p>";
        echo "<table border='1' style='border-collapse: collapse; width: 100%;'>";
        echo "<tr style='background: #f0f0f0;'><th>Tipo</th><th>Sección</th><th>Elemento</th><th>Tipo Respuesta</th></tr>";
        foreach (array_slice($elementos, 0, 10) as $elem) { // Solo primeros 10
            echo "<tr>";
            echo "<td>" . htmlspecialchars($elem['tipo_nombre']) . "</td>";
            echo "<td>" . htmlspecialchars($elem['seccion_nombre']) . "</td>";
            echo "<td>" . htmlspecialchars(substr($elem['descripcion'], 0, 50)) . "...</td>";
            echo "<td>" . $elem['tipo_respuesta'] . "</td>";
            echo "</tr>";
        }
        echo "</table>";
        if (count($elementos) > 10) {
            echo "<p><em>... y " . (count($elementos) - 10) . " elementos más</em></p>";
        }
    }
    
    // 7. Probar consulta específica
    if (isset($_GET['inmueble']) && isset($_GET['tipo'])) {
        echo "<h3>7. 🎯 Consulta Específica</h3>";
        $inmueble_id = $_GET['inmueble'];
        $tipo_id = $_GET['tipo'];
        
        echo "<p><strong>Buscando equipos para:</strong></p>";
        echo "<ul>";
        echo "<li>Inmueble ID: $inmueble_id</li>";
        echo "<li>Tipo ID: $tipo_id</li>";
        echo "</ul>";
        
        $query = "SELECT e.*, i.nombre as inmueble_nombre, t.nombre as tipo_nombre 
                  FROM equipos e 
                  LEFT JOIN inmuebles i ON e.inmueble_id = i.id 
                  LEFT JOIN tipos_inspeccion t ON e.tipo_inspeccion_id = t.id
                  WHERE e.inmueble_id = :inmueble_id AND e.tipo_inspeccion_id = :tipo_id 
                  AND e.estado_equipo = 'activo'";
        $stmt = $db->prepare($query);
        $stmt->bindParam(':inmueble_id', $inmueble_id);
        $stmt->bindParam(':tipo_id', $tipo_id);
        $stmt->execute();
        $equipos_filtrados = $stmt->fetchAll();
        
        if (empty($equipos_filtrados)) {
            echo "<p style='color: red;'>❌ No se encontraron equipos para esta combinación</p>";
        } else {
            echo "<p style='color: green;'>✅ " . count($equipos_filtrados) . " equipos encontrados:</p>";
            foreach ($equipos_filtrados as $eq) {
                echo "<div style='background: #e8f5e8; padding: 0.5rem; margin: 0.5rem 0; border-radius: 4px;'>";
                echo "<strong>" . htmlspecialchars($eq['codigo_equipo']) . "</strong> - ";
                echo htmlspecialchars($eq['ubicacion']);
                echo "</div>";
            }
        }
    }
    
} catch (Exception $e) {
    echo "<p style='color: red;'>❌ <strong>Error:</strong> " . $e->getMessage() . "</p>";
}

echo "<hr>";
echo "<h3>🚀 Enlaces de Prueba</h3>";
echo "<div style='display: flex; gap: 1rem; flex-wrap: wrap;'>";
echo "<a href='debug_equipos.php?inmueble=1&tipo=2' style='background: #007bff; color: white; padding: 0.5rem 1rem; text-decoration: none; border-radius: 4px;'>Probar Inmueble 1 + Tipo 2</a>";
echo "<a href='gestionar_equipos.php' style='background: #28a745; color: white; padding: 0.5rem 1rem; text-decoration: none; border-radius: 4px;'>Gestionar Equipos</a>";
echo "<a href='dashboard.php' style='background: #6c757d; color: white; padding: 0.5rem 1rem; text-decoration: none; border-radius: 4px;'>Dashboard</a>";
echo "</div>";
?>
