<?php
session_start();
require_once 'config/config.php';
require_once 'models/Inspeccion.php';
require_once 'models/FirmaInspeccion.php';

requireLogin();

$id = $_GET['id'] ?? 0;
if (!$id) {
    header('Location: inspecciones.php');
    exit();
}

$inspeccion = new Inspeccion();
$firmaModel = new FirmaInspeccion();

// Obtener datos de la inspección
$inspeccion_data = $inspeccion->getById($id);
if (!$inspeccion_data) {
    header('Location: inspecciones.php');
    exit();
}

// Procesar firma
if ($_POST && isset($_POST['guardar_firma'])) {
    $tipo_firma = $_POST['tipo_firma'];
    $nombre_firmante = $_POST['nombre_firmante'];
    $cargo_firmante = $_POST['cargo_firmante'] ?? '';
    $firma_base64 = $_POST['firma_data'];

    if ($firmaModel->guardarFirma($id, $tipo_firma, $nombre_firmante, $cargo_firmante, $firma_base64)) {
        $mensaje_exito = "✅ Firma guardada exitosamente";
    } else {
        $mensaje_error = "❌ Error al guardar la firma";
    }
}

// Obtener firmas existentes
$firmas_existentes = $firmaModel->getFirmasByInspeccion($id);
$firmas_por_tipo = [];
foreach ($firmas_existentes as $firma) {
    $firmas_por_tipo[$firma['tipo_firma']] = $firma;
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Firmar Inspección #<?php echo $id; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        .firma-canvas {
            border: 2px solid #ddd;
            border-radius: 8px;
            cursor: crosshair;
            background: white;
        }
        .firma-existente {
            max-width: 200px;
            max-height: 100px;
            border: 1px solid #ddd;
            border-radius: 5px;
        }
        .card-firma {
            border-left: 4px solid #28a745;
        }
        .card-firma.pendiente {
            border-left-color: #ffc107;
        }
        .signature-pad {
            position: relative;
            display: inline-block;
        }
    </style>
</head>
<body>
    <div class="container py-4">
        <!-- Header -->
        <div class="row">
            <div class="col-12">
                <div class="bg-primary text-white p-4 rounded mb-4">
                    <div class="d-flex justify-content-between align-items-center">
                        <div>
                            <h1><i class="fas fa-signature"></i> Firmar Inspección</h1>
                            <p class="mb-0">Inspección #<?php echo $id; ?> - <?php echo htmlspecialchars($inspeccion_data['inmueble_nombre']); ?></p>
                        </div>
                        <div class="text-end">
                            <a href="ver_inspeccion.php?id=<?php echo $id; ?>" class="btn btn-light">
                                <i class="fas fa-eye"></i> Ver Inspección
                            </a>
                            <a href="generar_pdf_simple.php?id=<?php echo $id; ?>" class="btn btn-success" target="_blank">
                                <i class="fas fa-file-pdf"></i> PDF Firmado
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Mensajes -->
        <?php if (isset($mensaje_exito)): ?>
            <div class="alert alert-success alert-dismissible">
                <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
                <?php echo $mensaje_exito; ?>
            </div>
        <?php endif; ?>

        <?php if (isset($mensaje_error)): ?>
            <div class="alert alert-danger"><?php echo $mensaje_error; ?></div>
        <?php endif; ?>

        <!-- Estado de Firmas -->
        <div class="row mb-4">
            <div class="col-12">
                <div class="card">
                    <div class="card-header">
                        <h5><i class="fas fa-clipboard-check"></i> Estado de Firmas</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-4">
                                <div class="card card-firma <?php echo isset($firmas_por_tipo['inspector']) ? '' : 'pendiente'; ?>">
                                    <div class="card-body text-center">
                                        <i class="fas fa-user-tie fa-2x mb-2 <?php echo isset($firmas_por_tipo['inspector']) ? 'text-success' : 'text-warning'; ?>"></i>
                                        <h6>Inspector</h6>
                                        <?php if (isset($firmas_por_tipo['inspector'])): ?>
                                            <span class="badge bg-success">Firmado</span>
                                            <div class="mt-2">
                                                <small><?php echo htmlspecialchars($firmas_por_tipo['inspector']['nombre_firmante']); ?></small>
                                            </div>
                                        <?php else: ?>
                                            <span class="badge bg-warning">Pendiente</span>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="card card-firma <?php echo isset($firmas_por_tipo['responsable']) ? '' : 'pendiente'; ?>">
                                    <div class="card-body text-center">
                                        <i class="fas fa-user-check fa-2x mb-2 <?php echo isset($firmas_por_tipo['responsable']) ? 'text-success' : 'text-warning'; ?>"></i>
                                        <h6>Responsable</h6>
                                        <?php if (isset($firmas_por_tipo['responsable'])): ?>
                                            <span class="badge bg-success">Firmado</span>
                                            <div class="mt-2">
                                                <small><?php echo htmlspecialchars($firmas_por_tipo['responsable']['nombre_firmante']); ?></small>
                                            </div>
                                        <?php else: ?>
                                            <span class="badge bg-warning">Pendiente</span>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="card card-firma <?php echo isset($firmas_por_tipo['contratista']) ? '' : 'pendiente'; ?>">
                                    <div class="card-body text-center">
                                        <i class="fas fa-hard-hat fa-2x mb-2 <?php echo isset($firmas_por_tipo['contratista']) ? 'text-success' : 'text-warning'; ?>"></i>
                                        <h6>Contratista</h6>
                                        <?php if (isset($firmas_por_tipo['contratista'])): ?>
                                            <span class="badge bg-success">Firmado</span>
                                            <div class="mt-2">
                                                <small><?php echo htmlspecialchars($firmas_por_tipo['contratista']['nombre_firmante']); ?></small>
                                            </div>
                                        <?php else: ?>
                                            <span class="badge bg-secondary">Opcional</span>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Formulario de Firma -->
        <div class="row">
            <div class="col-lg-8">
                <div class="card">
                    <div class="card-header">
                        <h5><i class="fas fa-pen"></i> Agregar Firma Digital</h5>
                    </div>
                    <div class="card-body">
                        <form method="POST" id="firmaForm">
                            <input type="hidden" name="guardar_firma" value="1">
                            <input type="hidden" name="firma_data" id="firmaData">
                            
                            <div class="row mb-3">
                                <div class="col-md-6">
                                    <label class="form-label">Tipo de Firma:</label>
                                    <select name="tipo_firma" class="form-control" required>
                                        <option value="">Seleccionar...</option>
                                        <option value="inspector" <?php echo !isset($firmas_por_tipo['inspector']) ? '' : 'disabled'; ?>>
                                            Inspector <?php echo isset($firmas_por_tipo['inspector']) ? '(Ya firmado)' : ''; ?>
                                        </option>
                                        <option value="responsable" <?php echo !isset($firmas_por_tipo['responsable']) ? '' : 'disabled'; ?>>
                                            Responsable del Inmueble <?php echo isset($firmas_por_tipo['responsable']) ? '(Ya firmado)' : ''; ?>
                                        </option>
                                        <option value="contratista" <?php echo !isset($firmas_por_tipo['contratista']) ? '' : 'disabled'; ?>>
                                            Contratista <?php echo isset($firmas_por_tipo['contratista']) ? '(Ya firmado)' : ''; ?>
                                        </option>
                                    </select>
                                </div>
                                <div class="col-md-6">
                                    <label class="form-label">Nombre Completo:</label>
                                    <input type="text" name="nombre_firmante" class="form-control" required 
                                           placeholder="Nombre de quien firma">
                                </div>
                            </div>
                            
                            <div class="mb-3">
                                <label class="form-label">Cargo (Opcional):</label>
                                <input type="text" name="cargo_firmante" class="form-control" 
                                       placeholder="Ej: Inspector Certificado, Administrador, etc.">
                            </div>
                            
                            <div class="mb-3">
                                <label class="form-label">Firma Digital:</label>
                                <div class="signature-pad">
                                    <canvas id="firmaCanvas" class="firma-canvas" width="600" height="200"></canvas>
                                    <div class="mt-2">
                                        <button type="button" class="btn btn-outline-secondary btn-sm" onclick="limpiarFirma()">
                                            <i class="fas fa-eraser"></i> Limpiar
                                        </button>
                                        <button type="button" class="btn btn-outline-info btn-sm" onclick="cambiarColor('black')">Negro</button>
                                        <button type="button" class="btn btn-outline-primary btn-sm" onclick="cambiarColor('blue')">Azul</button>
                                        <small class="text-muted ms-3">Dibuje su firma en el recuadro</small>
                                    </div>
                                </div>
                            </div>
                            
                            <div class="text-center">
                                <button type="submit" class="btn btn-success btn-lg" id="btnGuardarFirma" disabled>
                                    <i class="fas fa-save"></i> Guardar Firma
                                </button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
            
            <div class="col-lg-4">
                <!-- Firmas Existentes -->
                <div class="card">
                    <div class="card-header">
                        <h6><i class="fas fa-list"></i> Firmas Registradas</h6>
                    </div>
                    <div class="card-body">
                        <?php if (empty($firmas_existentes)): ?>
                            <p class="text-muted text-center">
                                <i class="fas fa-signature fa-2x mb-2"></i><br>
                                No hay firmas registradas
                            </p>
                        <?php else: ?>
                            <?php foreach ($firmas_existentes as $firma): ?>
                                <div class="border rounded p-2 mb-2">
                                    <div class="d-flex justify-content-between align-items-start">
                                        <div>
                                            <strong><?php echo ucfirst($firma['tipo_firma']); ?></strong><br>
                                            <small><?php echo htmlspecialchars($firma['nombre_firmante']); ?></small><br>
                                            <?php if ($firma['cargo_firmante']): ?>
                                                <small class="text-muted"><?php echo htmlspecialchars($firma['cargo_firmante']); ?></small><br>
                                            <?php endif; ?>
                                            <small class="text-muted"><?php echo date('d/m/Y H:i', strtotime($firma['fecha_firma'])); ?></small>
                                        </div>
                                        <img src="<?php echo $firma['firma_base64']; ?>" class="firma-existente" alt="Firma">
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </div>
                </div>

                <!-- Información -->
                <div class="card mt-3">
                    <div class="card-header">
                        <h6><i class="fas fa-info-circle"></i> Información</h6>
                    </div>
                    <div class="card-body">
                        <ul class="list-unstyled">
                            <li><i class="fas fa-check text-success"></i> Inspector: Obligatorio</li>
                            <li><i class="fas fa-check text-success"></i> Responsable: Obligatorio</li>
                            <li><i class="fas fa-info text-info"></i> Contratista: Opcional</li>
                        </ul>
                        <hr>
                        <small class="text-muted">
                            Las firmas digitales quedan registradas con fecha, hora e IP para garantizar la autenticidad.
                        </small>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Variables para el canvas de firma
        let canvas = document.getElementById('firmaCanvas');
        let ctx = canvas.getContext('2d');
        let dibujando = false;
        let colorActual = 'black';

        // Configurar canvas
        ctx.strokeStyle = colorActual;
        ctx.lineWidth = 2;
        ctx.lineCap = 'round';

        // Eventos del mouse
        canvas.addEventListener('mousedown', iniciarDibujo);
        canvas.addEventListener('mousemove', dibujar);
        canvas.addEventListener('mouseup', terminarDibujo);
        canvas.addEventListener('mouseout', terminarDibujo);

        // Eventos táctiles para móviles
        canvas.addEventListener('touchstart', function(e) {
            e.preventDefault();
            let touch = e.touches[0];
            let mouseEvent = new MouseEvent('mousedown', {
                clientX: touch.clientX,
                clientY: touch.clientY
            });
            canvas.dispatchEvent(mouseEvent);
        });

        canvas.addEventListener('touchmove', function(e) {
            e.preventDefault();
            let touch = e.touches[0];
            let mouseEvent = new MouseEvent('mousemove', {
                clientX: touch.clientX,
                clientY: touch.clientY
            });
            canvas.dispatchEvent(mouseEvent);
        });

        canvas.addEventListener('touchend', function(e) {
            e.preventDefault();
            let mouseEvent = new MouseEvent('mouseup', {});
            canvas.dispatchEvent(mouseEvent);
        });

        function iniciarDibujo(e) {
            dibujando = true;
            let rect = canvas.getBoundingClientRect();
            ctx.beginPath();
            ctx.moveTo(e.clientX - rect.left, e.clientY - rect.top);
            habilitarBotonGuardar();
        }

        function dibujar(e) {
            if (!dibujando) return;
            let rect = canvas.getBoundingClientRect();
            ctx.lineTo(e.clientX - rect.left, e.clientY - rect.top);
            ctx.stroke();
        }

        function terminarDibujo() {
            dibujando = false;
            ctx.beginPath();
        }

        function limpiarFirma() {
            ctx.clearRect(0, 0, canvas.width, canvas.height);
            document.getElementById('btnGuardarFirma').disabled = true;
        }

        function cambiarColor(color) {
            colorActual = color;
            ctx.strokeStyle = color;
        }

        function habilitarBotonGuardar() {
            document.getElementById('btnGuardarFirma').disabled = false;
        }

        // Enviar formulario
        document.getElementById('firmaForm').addEventListener('submit', function(e) {
            e.preventDefault();
            
            // Convertir canvas a base64
            let firmaDataURL = canvas.toDataURL('image/png');
            document.getElementById('firmaData').value = firmaDataURL;
            
            // Validar que hay firma
            if (firmaDataURL === 'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAADUlEQVR42mNkYPhfDwAChwGA60e6kgAAAABJRU5ErkJggg==') {
                alert('⚠️ Por favor dibuje su firma antes de guardar.');
                return;
            }
            
            // Enviar formulario
            this.submit();
        });

        console.log('✅ Sistema de firmas digitales cargado');
    </script>
</body>
</html>
