<?php
// Configuración directa de la base de datos
$host = 'localhost';
$dbname = 'sistema_inspeccion';
$username = 'root';
$password = '';

echo "<h2>🔧 Reparador Directo del Sistema de Aprobación</h2>";
echo "<style>
    body { font-family: Arial, sans-serif; margin: 20px; }
    .success { background: #d4edda; padding: 10px; border-radius: 5px; margin: 10px 0; }
    .error { background: #f8d7da; padding: 10px; border-radius: 5px; margin: 10px 0; }
    .info { background: #d1ecf1; padding: 10px; border-radius: 5px; margin: 10px 0; }
    .warning { background: #fff3cd; padding: 10px; border-radius: 5px; margin: 10px 0; }
</style>";

try {
    // Conectar directamente a la base de datos
    $pdo = new PDO("mysql:host=$host;dbname=$dbname;charset=utf8", $username, $password);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    
    echo "<div class='success'>✅ Conexión a la base de datos exitosa</div>";
    
    // Verificar si la tabla inspecciones existe
    $stmt = $pdo->query("SHOW TABLES LIKE 'inspecciones'");
    if ($stmt->rowCount() == 0) {
        echo "<div class='error'>❌ La tabla 'inspecciones' no existe</div>";
        exit();
    }
    
    echo "<div class='success'>✅ Tabla 'inspecciones' encontrada</div>";
    
    // Obtener estructura actual de la tabla
    $stmt = $pdo->query("DESCRIBE inspecciones");
    $existing_columns = [];
    while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
        $existing_columns[] = $row['Field'];
    }
    
    echo "<div class='info'>📋 Campos actuales en la tabla: " . implode(', ', $existing_columns) . "</div>";
    
    // Campos que necesitamos agregar
    $campos_necesarios = [
        'aprobador_id' => 'INT NULL COMMENT "ID del usuario que aprobó"',
        'fecha_aprobacion' => 'DATETIME NULL COMMENT "Fecha de aprobación"',
        'comentarios_aprobacion' => 'TEXT NULL COMMENT "Comentarios de aprobación"',
        'rechazador_id' => 'INT NULL COMMENT "ID del usuario que rechazó"',
        'fecha_rechazo' => 'DATETIME NULL COMMENT "Fecha de rechazo"',
        'motivo_rechazo' => 'TEXT NULL COMMENT "Motivo del rechazo"'
    ];
    
    $campos_agregados = 0;
    $campos_existentes = 0;
    
    echo "<h3>🔧 Procesando campos:</h3>";
    
    foreach ($campos_necesarios as $campo => $definicion) {
        if (in_array($campo, $existing_columns)) {
            echo "<div class='info'>✅ <strong>$campo</strong> - Ya existe</div>";
            $campos_existentes++;
        } else {
            echo "<div class='warning'>⏳ <strong>$campo</strong> - Agregando...</div>";
            
            try {
                $sql = "ALTER TABLE inspecciones ADD COLUMN $campo $definicion";
                $pdo->exec($sql);
                echo "<div class='success'>✅ <strong>$campo</strong> - Agregado exitosamente</div>";
                $campos_agregados++;
            } catch (Exception $e) {
                echo "<div class='error'>❌ <strong>$campo</strong> - Error: " . $e->getMessage() . "</div>";
            }
        }
    }
    
    echo "<hr>";
    echo "<h3>📊 Resumen Final:</h3>";
    echo "<div class='info'>";
    echo "<p>✅ Campos ya existentes: $campos_existentes</p>";
    echo "<p>➕ Campos agregados: $campos_agregados</p>";
    echo "<p>📋 Total de campos de aprobación: " . ($campos_existentes + $campos_agregados) . "/" . count($campos_necesarios) . "</p>";
    echo "</div>";
    
    if (($campos_existentes + $campos_agregados) == count($campos_necesarios)) {
        echo "<div class='success'>";
        echo "<h4>🎉 ¡Sistema de Aprobación Completamente Instalado!</h4>";
        echo "<p>Todos los campos necesarios están disponibles.</p>";
        echo "</div>";
        
        // Verificar si hay inspecciones completadas para probar
        $stmt = $pdo->query("SELECT COUNT(*) as total FROM inspecciones WHERE estado = 'completada'");
        $completadas = $stmt->fetch(PDO::FETCH_ASSOC)['total'];
        
        if ($completadas > 0) {
            echo "<div class='success'>";
            echo "<h4>🚀 Listo para Probar:</h4>";
            echo "<p>Hay $completadas inspección(es) completada(s) disponible(s) para aprobar.</p>";
            echo "<p><a href='inspecciones.php' style='background: #007bff; color: white; padding: 10px 20px; text-decoration: none; border-radius: 5px;'>Ver Inspecciones</a></p>";
            echo "</div>";
        } else {
            echo "<div class='warning'>";
            echo "<h4>⚠️ No hay inspecciones completadas</h4>";
            echo "<p>Necesitas tener al menos una inspección en estado 'completada' para probar la aprobación.</p>";
            echo "<p><a href='crear_borrador.php' style='background: #28a745; color: white; padding: 10px 20px; text-decoration: none; border-radius: 5px;'>Crear Inspección de Prueba</a></p>";
            echo "</div>";
        }
        
        // Mostrar estructura final de la tabla
        echo "<h3>📋 Estructura Final de la Tabla:</h3>";
        $stmt = $pdo->query("DESCRIBE inspecciones");
        echo "<table border='1' style='border-collapse: collapse; width: 100%;'>";
        echo "<tr style='background: #f8f9fa;'><th>Campo</th><th>Tipo</th><th>Nulo</th><th>Comentario</th></tr>";
        while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
            $highlight = in_array($row['Field'], array_keys($campos_necesarios)) ? 'background: #d4edda;' : '';
            echo "<tr style='$highlight'>";
            echo "<td><strong>" . $row['Field'] . "</strong></td>";
            echo "<td>" . $row['Type'] . "</td>";
            echo "<td>" . $row['Null'] . "</td>";
            echo "<td>" . ($row['Comment'] ?? '') . "</td>";
            echo "</tr>";
        }
        echo "</table>";
        
    } else {
        echo "<div class='error'>";
        echo "<h4>❌ Instalación Incompleta</h4>";
        echo "<p>Algunos campos no se pudieron agregar. Revisa los errores arriba.</p>";
        echo "</div>";
    }
    
} catch (Exception $e) {
    echo "<div class='error'>";
    echo "<h4>❌ Error de Conexión</h4>";
    echo "<p>No se pudo conectar a la base de datos:</p>";
    echo "<p><strong>Error:</strong> " . $e->getMessage() . "</p>";
    echo "<p><strong>Verifica:</strong></p>";
    echo "<ul>";
    echo "<li>Que XAMPP esté ejecutándose</li>";
    echo "<li>Que MySQL esté activo</li>";
    echo "<li>Que la base de datos 'sistema_inspeccion' exista</li>";
    echo "<li>Que las credenciales sean correctas (usuario: root, sin contraseña)</li>";
    echo "</ul>";
    echo "</div>";
}

echo "<hr>";
echo "<h3>🔗 Enlaces Útiles:</h3>";
echo "<p><a href='dashboard.php'>🏠 Volver al Dashboard</a></p>";
echo "<p><a href='inspecciones.php'>📋 Ver Inspecciones</a></p>";
echo "<p><a href='aprobar_inspeccion.php?id=1'>🧪 Probar Aprobación (ID=1)</a></p>";
?>
