<?php
require_once 'config/config.php';
require_once 'models/Equipo.php';
require_once 'models/Inmueble.php';
require_once 'models/TipoInspeccion.php';

requireLogin();

$equipo = new Equipo();
$inmueble = new Inmueble();
$tipoInspeccion = new TipoInspeccion();

$message = '';
$message_type = '';

// Procesar formulario
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (isset($_POST['action'])) {
        switch ($_POST['action']) {
            case 'create':
                // Validar datos requeridos
                if (empty($_POST['inmueble_id']) || empty($_POST['tipo_inspeccion_id']) || 
                    empty($_POST['codigo_equipo']) || empty($_POST['ubicacion'])) {
                    $message = 'Por favor completa todos los campos obligatorios';
                    $message_type = 'danger';
                    break;
                }
                
                $data = [
                    'inmueble_id' => (int)$_POST['inmueble_id'],
                    'tipo_inspeccion_id' => (int)$_POST['tipo_inspeccion_id'],
                    'codigo_equipo' => htmlspecialchars(trim($_POST['codigo_equipo'])),
                    'numero_serie' => !empty($_POST['numero_serie']) ? htmlspecialchars(trim($_POST['numero_serie'])) : null,
                    'ubicacion' => htmlspecialchars(trim($_POST['ubicacion'])),
                    'descripcion' => !empty($_POST['descripcion']) ? htmlspecialchars(trim($_POST['descripcion'])) : null,
                    'fecha_instalacion' => !empty($_POST['fecha_instalacion']) ? $_POST['fecha_instalacion'] : null,
                    'observaciones' => !empty($_POST['observaciones']) ? htmlspecialchars(trim($_POST['observaciones'])) : null
                ];
                
                $result = $equipo->create($data);
                if ($result) {
                    $message = 'Equipo registrado exitosamente con ID: ' . $result;
                    $message_type = 'success';
                    // Limpiar formulario redirigiendo
                    header('Location: gestionar_equipos.php?success=1');
                    exit();
                } else {
                    $message = 'Error al registrar el equipo. Verifica que el código no esté duplicado.';
                    $message_type = 'danger';
                }
                break;
                
            case 'update':
                $id = $_POST['equipo_id'];
                $data = [
                    'codigo_equipo' => htmlspecialchars($_POST['codigo_equipo']),
                    'numero_serie' => htmlspecialchars($_POST['numero_serie']),
                    'ubicacion' => htmlspecialchars($_POST['ubicacion']),
                    'descripcion' => htmlspecialchars($_POST['descripcion']),
                    'fecha_instalacion' => $_POST['fecha_instalacion'] ?: null,
                    'estado_equipo' => $_POST['estado_equipo'],
                    'observaciones' => htmlspecialchars($_POST['observaciones'])
                ];
                
                if ($equipo->update($id, $data)) {
                    $message = 'Equipo actualizado exitosamente';
                    $message_type = 'success';
                } else {
                    $message = 'Error al actualizar el equipo';
                    $message_type = 'danger';
                }
                break;
        }
    }
}

// Obtener datos para filtros
$inmuebles = $inmueble->getAll();
$tipos_inspeccion = $tipoInspeccion->getAll();

// Filtros
$filtro_inmueble = $_GET['inmueble'] ?? '';
$filtro_tipo = $_GET['tipo'] ?? '';
$filtro_estado = $_GET['estado'] ?? '';

// Obtener equipos
$equipos = [];
if ($filtro_inmueble && $filtro_tipo) {
    $equipos = $equipo->getByInmuebleYTipo($filtro_inmueble, $filtro_tipo);
}

// Generar código automático para AJAX
if (isset($_GET['generar_codigo']) && $_GET['inmueble_id'] && $_GET['tipo_id']) {
    header('Content-Type: application/json');
    echo json_encode([
        'codigo' => $equipo->generarCodigoAutomatico($_GET['inmueble_id'], $_GET['tipo_id'])
    ]);
    exit();
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Gestionar Equipos - <?php echo APP_NAME; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        body { 
            background-color: #f8f9fa; 
            font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', sans-serif;
        }
        .navbar { 
            background: linear-gradient(135deg, #667eea 0%, #764ba2 100%); 
        }
        .card { 
            border: none; 
            border-radius: 15px; 
            box-shadow: 0 5px 15px rgba(0,0,0,0.08); 
            margin-bottom: 1.5rem;
        }
        .equipo-card {
            border-left: 4px solid #667eea;
            transition: all 0.3s;
        }
        .equipo-card:hover {
            transform: translateY(-2px);
            box-shadow: 0 8px 25px rgba(0,0,0,0.15);
        }
        .estado-badge {
            padding: 4px 8px;
            border-radius: 12px;
            font-size: 0.75rem;
            font-weight: 600;
        }
        .estado-activo { background: #d4edda; color: #155724; }
        .estado-inactivo { background: #f8d7da; color: #721c24; }
        .estado-mantenimiento { background: #fff3cd; color: #856404; }
        .estado-retirado { background: #e2e3e5; color: #6c757d; }
    </style>
</head>
<body>
    <!-- Navbar -->
    <nav class="navbar navbar-expand-lg navbar-dark">
        <div class="container-fluid">
            <a class="navbar-brand" href="dashboard.php">
                <i class="fas fa-cogs me-2"></i>Gestionar Equipos
            </a>
            <div class="navbar-nav ms-auto">
                <a class="nav-link" href="inspecciones.php">
                    <i class="fas fa-clipboard-list me-2"></i>Inspecciones
                </a>
                <a class="nav-link" href="dashboard.php">
                    <i class="fas fa-arrow-left me-2"></i>Dashboard
                </a>
            </div>
        </div>
    </nav>

    <div class="container-fluid py-4">
        <!-- Alert -->
        <?php if ($message): ?>
            <div class="alert alert-<?php echo $message_type; ?> alert-dismissible fade show" role="alert">
                <i class="fas fa-<?php echo $message_type === 'success' ? 'check-circle' : 'exclamation-triangle'; ?> me-2"></i>
                <?php echo $message; ?>
                <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
            </div>
        <?php endif; ?>

        <div class="row">
            <!-- Formulario de Registro -->
            <div class="col-lg-4">
                <div class="card">
                    <div class="card-header">
                        <h5 class="mb-0">
                            <i class="fas fa-plus me-2"></i>Registrar Nuevo Equipo
                        </h5>
                    </div>
                    <div class="card-body">
                        <form method="POST" id="equipoForm">
                            <input type="hidden" name="action" value="create">
                            
                            <div class="mb-3">
                                <label class="form-label">Inmueble *</label>
                                <select class="form-select" name="inmueble_id" id="inmueble_id" required>
                                    <option value="">Seleccionar inmueble...</option>
                                    <?php foreach ($inmuebles as $inm): ?>
                                        <option value="<?php echo $inm['id']; ?>">
                                            <?php echo htmlspecialchars($inm['nombre']); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            
                            <div class="mb-3">
                                <label class="form-label">Tipo de Equipo *</label>
                                <select class="form-select" name="tipo_inspeccion_id" id="tipo_inspeccion_id" required>
                                    <option value="">Seleccionar tipo...</option>
                                    <?php foreach ($tipos_inspeccion as $tipo): ?>
                                        <option value="<?php echo $tipo['id']; ?>">
                                            <?php echo htmlspecialchars($tipo['nombre']); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            
                            <div class="mb-3">
                                <label class="form-label">Código del Equipo *</label>
                                <div class="input-group">
                                    <input type="text" class="form-control" name="codigo_equipo" id="codigo_equipo" required>
                                    <button type="button" class="btn btn-outline-secondary" id="generarCodigo">
                                        <i class="fas fa-magic"></i>
                                    </button>
                                </div>
                                <small class="text-muted">Ej: EXT-001, BOMBA-001, EPP-001</small>
                            </div>
                            
                            <div class="mb-3">
                                <label class="form-label">Número de Serie</label>
                                <input type="text" class="form-control" name="numero_serie">
                            </div>
                            
                            <div class="mb-3">
                                <label class="form-label">Ubicación *</label>
                                <input type="text" class="form-control" name="ubicacion" required 
                                       placeholder="Ej: Planta Baja - Recepción">
                            </div>
                            
                            <div class="mb-3">
                                <label class="form-label">Descripción</label>
                                <textarea class="form-control" name="descripcion" rows="2" 
                                          placeholder="Ej: Extintor ABC 6kg"></textarea>
                            </div>
                            
                            <div class="mb-3">
                                <label class="form-label">Fecha de Instalación</label>
                                <input type="date" class="form-control" name="fecha_instalacion">
                            </div>
                            
                            <div class="mb-3">
                                <label class="form-label">Observaciones</label>
                                <textarea class="form-control" name="observaciones" rows="2"></textarea>
                            </div>
                            
                            <button type="submit" class="btn btn-primary w-100">
                                <i class="fas fa-save me-2"></i>Registrar Equipo
                            </button>
                        </form>
                    </div>
                </div>
            </div>

            <!-- Lista de Equipos -->
            <div class="col-lg-8">
                <!-- Filtros -->
                <div class="card mb-3">
                    <div class="card-body">
                        <form method="GET" class="row g-3">
                            <div class="col-md-4">
                                <label class="form-label">Inmueble</label>
                                <select class="form-select" name="inmueble">
                                    <option value="">Todos los inmuebles</option>
                                    <?php foreach ($inmuebles as $inm): ?>
                                        <option value="<?php echo $inm['id']; ?>" <?php echo $filtro_inmueble == $inm['id'] ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($inm['nombre']); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            <div class="col-md-4">
                                <label class="form-label">Tipo de Equipo</label>
                                <select class="form-select" name="tipo">
                                    <option value="">Todos los tipos</option>
                                    <?php foreach ($tipos_inspeccion as $tipo): ?>
                                        <option value="<?php echo $tipo['id']; ?>" <?php echo $filtro_tipo == $tipo['id'] ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($tipo['nombre']); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            <div class="col-md-4">
                                <label class="form-label">&nbsp;</label>
                                <div class="d-flex gap-2">
                                    <button type="submit" class="btn btn-primary">
                                        <i class="fas fa-search"></i> Buscar
                                    </button>
                                    <a href="gestionar_equipos.php" class="btn btn-outline-secondary">
                                        <i class="fas fa-times"></i>
                                    </a>
                                </div>
                            </div>
                        </form>
                    </div>
                </div>

                <!-- Equipos -->
                <div class="card">
                    <div class="card-header">
                        <h5 class="mb-0">
                            <i class="fas fa-list me-2"></i>
                            Equipos Registrados
                            <?php if (!empty($equipos)): ?>
                                <span class="badge bg-primary"><?php echo count($equipos); ?></span>
                            <?php endif; ?>
                        </h5>
                    </div>
                    <div class="card-body">
                        <?php if (empty($equipos) && ($filtro_inmueble || $filtro_tipo)): ?>
                            <div class="text-center py-4">
                                <i class="fas fa-search fa-3x text-muted mb-3"></i>
                                <h5 class="text-muted">No se encontraron equipos</h5>
                                <p class="text-muted">Selecciona un inmueble y tipo de equipo para ver los equipos registrados</p>
                            </div>
                        <?php elseif (empty($equipos)): ?>
                            <div class="text-center py-4">
                                <i class="fas fa-cogs fa-3x text-muted mb-3"></i>
                                <h5 class="text-muted">Selecciona filtros</h5>
                                <p class="text-muted">Elige un inmueble y tipo de equipo para ver los equipos</p>
                            </div>
                        <?php else: ?>
                            <div class="row">
                                <?php foreach ($equipos as $eq): ?>
                                    <div class="col-md-6 mb-3">
                                        <div class="card equipo-card h-100">
                                            <div class="card-body">
                                                <div class="d-flex justify-content-between align-items-start mb-2">
                                                    <h6 class="card-title mb-0">
                                                        <i class="fas fa-tag me-2"></i>
                                                        <?php echo htmlspecialchars($eq['codigo_equipo']); ?>
                                                    </h6>
                                                    <span class="estado-badge estado-<?php echo $eq['estado_equipo']; ?>">
                                                        <?php echo ucfirst($eq['estado_equipo']); ?>
                                                    </span>
                                                </div>
                                                
                                                <p class="card-text">
                                                    <small class="text-muted">
                                                        <i class="fas fa-map-marker-alt me-1"></i>
                                                        <?php echo htmlspecialchars($eq['ubicacion']); ?>
                                                    </small>
                                                </p>
                                                
                                                <?php if ($eq['numero_serie']): ?>
                                                    <p class="card-text">
                                                        <small class="text-muted">
                                                            <i class="fas fa-barcode me-1"></i>
                                                            S/N: <?php echo htmlspecialchars($eq['numero_serie']); ?>
                                                        </small>
                                                    </p>
                                                <?php endif; ?>
                                                
                                                <?php if ($eq['descripcion']): ?>
                                                    <p class="card-text">
                                                        <?php echo htmlspecialchars($eq['descripcion']); ?>
                                                    </p>
                                                <?php endif; ?>
                                                
                                                <div class="d-flex gap-2 mt-3">
                                                    <button class="btn btn-sm btn-outline-primary" 
                                                            onclick="editarEquipo(<?php echo $eq['id']; ?>)">
                                                        <i class="fas fa-edit"></i>
                                                    </button>
                                                    <a href="nueva_inspeccion.php?inmueble=<?php echo $eq['inmueble_id']; ?>&tipo=<?php echo $eq['tipo_inspeccion_id']; ?>&equipo=<?php echo $eq['id']; ?>" 
                                                       class="btn btn-sm btn-success">
                                                        <i class="fas fa-clipboard-check"></i> Inspeccionar
                                                    </a>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Generar código automático
        document.getElementById('generarCodigo').addEventListener('click', function() {
            const inmuebleId = document.getElementById('inmueble_id').value;
            const tipoId = document.getElementById('tipo_inspeccion_id').value;
            
            if (!inmuebleId || !tipoId) {
                alert('Selecciona primero el inmueble y tipo de equipo');
                return;
            }
            
            fetch(`gestionar_equipos.php?generar_codigo=1&inmueble_id=${inmuebleId}&tipo_id=${tipoId}`)
                .then(response => response.json())
                .then(data => {
                    document.getElementById('codigo_equipo').value = data.codigo;
                })
                .catch(error => {
                    console.error('Error:', error);
                    alert('Error al generar código');
                });
        });
        
        function editarEquipo(id) {
            // Implementar modal de edición
            alert('Función de edición en desarrollo. ID: ' + id);
        }
    </script>
</body>
</html>
