<?php
require_once 'config/config.php';
require_once 'models/Inspeccion.php';
require_once 'models/Inmueble.php';
require_once 'models/TipoInspeccion.php';
require_once 'models/Equipo.php';

requireLogin();

$inspeccion = new Inspeccion();
$inmueble = new Inmueble();
$tipoInspeccion = new TipoInspeccion();
$equipo = new Equipo();

$inmuebles = $inmueble->getAll();
$tipos_inspeccion = $tipoInspeccion->getActive();

$message = '';
$message_type = '';

// Variables para el flujo
$paso = $_GET['paso'] ?? 1;
$inmueble_seleccionado = $_GET['inmueble'] ?? $_POST['inmueble_id'] ?? null;
$tipo_seleccionado = $_GET['tipo'] ?? $_POST['tipo_inspeccion_id'] ?? null;

// Obtener equipos disponibles
$equipos_disponibles = [];
$elementos_inspeccion = [];

if ($inmueble_seleccionado && $tipo_seleccionado) {
    $equipos_disponibles = $equipo->getByInmuebleYTipo($inmueble_seleccionado, $tipo_seleccionado);
    $elementos_inspeccion = $inspeccion->getElementosInspeccion($tipo_seleccionado);
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Inspección por Equipos - <?php echo APP_NAME; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        :root {
            --primary: #0070f3;
            --success: #00d084;
            --warning: #f5a623;
            --danger: #e00;
        }

        body {
            font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', sans-serif;
            background-color: #fafafa;
        }

        .header {
            background: white;
            border-bottom: 1px solid #e4e4e7;
            padding: 1rem 0;
            position: sticky;
            top: 0;
            z-index: 50;
        }

        .step-indicator {
            background: linear-gradient(135deg, var(--primary), #0051cc);
            color: white;
            padding: 2rem;
            border-radius: 15px;
            margin-bottom: 2rem;
            text-align: center;
        }

        .equipment-card {
            border: 2px solid #e4e4e7;
            border-radius: 12px;
            padding: 1.5rem;
            margin-bottom: 1rem;
            transition: all 0.3s;
            background: white;
            cursor: pointer;
        }

        .equipment-card.selected {
            border-color: var(--success);
            background: #f0fdf4;
            box-shadow: 0 4px 12px rgba(0,208,132,0.2);
        }

        .equipment-code {
            font-size: 1.25rem;
            font-weight: 700;
            color: var(--primary);
        }

        .equipment-location {
            color: #666;
            font-size: 0.9rem;
        }

        .inspection-section {
            background: white;
            border-radius: 12px;
            padding: 2rem;
            margin-bottom: 2rem;
            border: 1px solid #e4e4e7;
        }

        .equipment-inspection {
            border: 2px solid #e4e4e7;
            border-radius: 12px;
            padding: 1.5rem;
            margin-bottom: 2rem;
            background: #fafafa;
        }

        .equipment-inspection.active {
            border-color: var(--primary);
            background: white;
        }

        .response-options {
            display: flex;
            gap: 0.75rem;
            margin: 1rem 0;
        }

        .response-option {
            flex: 1;
        }

        .response-option input[type="radio"] {
            display: none;
        }

        .response-label {
            display: flex;
            align-items: center;
            justify-content: center;
            gap: 0.5rem;
            padding: 0.75rem;
            border: 2px solid #e4e4e7;
            border-radius: 8px;
            cursor: pointer;
            transition: all 0.2s;
            font-weight: 500;
            text-align: center;
        }

        .response-si input:checked + .response-label {
            background: var(--success);
            border-color: var(--success);
            color: white;
        }

        .response-no input:checked + .response-label {
            background: var(--danger);
            border-color: var(--danger);
            color: white;
        }

        .response-nc input:checked + .response-label {
            background: var(--warning);
            border-color: var(--warning);
            color: white;
        }

        .debug-info {
            background: #f8f9fa;
            border: 1px solid #dee2e6;
            border-radius: 8px;
            padding: 1rem;
            margin: 1rem 0;
            font-family: monospace;
            font-size: 0.9rem;
        }
    </style>
</head>
<body>
    <!-- Header -->
    <header class="header">
        <div class="container-fluid">
            <div class="d-flex justify-content-between align-items-center">
                <a href="dashboard.php" class="text-decoration-none text-dark fw-bold">
                    <i class="fas fa-fire-extinguisher me-2"></i>
                    <?php echo APP_NAME; ?>
                </a>
                <div>
                    <a href="dashboard.php" class="btn btn-sm btn-outline-primary">
                        <i class="fas fa-arrow-left"></i> Volver
                    </a>
                </div>
            </div>
        </div>
    </header>

    <div class="container-fluid py-4">
        <!-- Step Indicator -->
        <div class="step-indicator">
            <h1 class="mb-3">
                <i class="fas fa-clipboard-check me-3"></i>
                Inspección por Equipos Específicos
            </h1>
            <p class="mb-0">Inspecciona cada equipo individualmente con total trazabilidad</p>
        </div>

        <?php if ($paso == 1 || !$inmueble_seleccionado || !$tipo_seleccionado): ?>
            <!-- Paso 1: Selección de Inmueble y Tipo -->
            <div class="row justify-content-center">
                <div class="col-lg-8">
                    <div class="inspection-section">
                        <h3 class="mb-4">
                            <i class="fas fa-building me-2"></i>
                            Paso 1: Selecciona Inmueble y Tipo de Equipo
                        </h3>
                        
                        <form method="GET">
                            <input type="hidden" name="paso" value="2">
                            
                            <div class="row">
                                <div class="col-md-6 mb-3">
                                    <label class="form-label">Inmueble *</label>
                                    <select class="form-control" name="inmueble" required>
                                        <option value="">Seleccionar inmueble...</option>
                                        <?php foreach ($inmuebles as $inm): ?>
                                            <option value="<?php echo $inm['id']; ?>" <?php echo $inmueble_seleccionado == $inm['id'] ? 'selected' : ''; ?>>
                                                <?php echo htmlspecialchars($inm['nombre']); ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                                
                                <div class="col-md-6 mb-3">
                                    <label class="form-label">Tipo de Equipo *</label>
                                    <select class="form-control" name="tipo" required>
                                        <option value="">Seleccionar tipo...</option>
                                        <?php foreach ($tipos_inspeccion as $tipo): ?>
                                            <option value="<?php echo $tipo['id']; ?>" <?php echo $tipo_seleccionado == $tipo['id'] ? 'selected' : ''; ?>>
                                                <?php echo htmlspecialchars($tipo['nombre']); ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                            
                            <div class="text-center">
                                <button type="submit" class="btn btn-primary btn-lg">
                                    <i class="fas fa-search me-2"></i>
                                    Buscar Equipos Disponibles
                                </button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>

        <?php elseif (empty($equipos_disponibles)): ?>
            <!-- No hay equipos -->
            <div class="row justify-content-center">
                <div class="col-lg-8">
                    <div class="inspection-section text-center">
                        <i class="fas fa-exclamation-triangle fa-4x text-warning mb-3"></i>
                        <h3>No hay equipos registrados</h3>
                        <p class="text-muted">No se encontraron equipos para este inmueble y tipo de inspección.</p>
                        <div class="d-flex gap-2 justify-content-center">
                            <a href="gestionar_equipos.php" class="btn btn-success">
                                <i class="fas fa-plus me-2"></i>Registrar Equipos
                            </a>
                            <a href="?paso=1" class="btn btn-secondary">
                                <i class="fas fa-arrow-left me-2"></i>Volver
                            </a>
                        </div>
                    </div>
                </div>
            </div>

        <?php else: ?>
            <!-- Paso 2: Selección de Equipos e Inspección -->
            <div class="row">
                <div class="col-lg-4">
                    <div class="inspection-section">
                        <h4 class="mb-3">
                            <i class="fas fa-info-circle me-2"></i>
                            Información General
                        </h4>
                        
                        <div class="mb-3">
                            <strong>Inmueble:</strong><br>
                            <?php 
                            $inmueble_info = array_filter($inmuebles, function($inm) use ($inmueble_seleccionado) {
                                return $inm['id'] == $inmueble_seleccionado;
                            });
                            echo htmlspecialchars(reset($inmueble_info)['nombre']);
                            ?>
                        </div>
                        
                        <div class="mb-3">
                            <strong>Tipo de Equipo:</strong><br>
                            <?php 
                            $tipo_info = array_filter($tipos_inspeccion, function($tipo) use ($tipo_seleccionado) {
                                return $tipo['id'] == $tipo_seleccionado;
                            });
                            echo htmlspecialchars(reset($tipo_info)['nombre']);
                            ?>
                        </div>
                        
                        <div class="mb-3">
                            <strong>Inspector:</strong><br>
                            <?php echo $_SESSION['user_name']; ?>
                        </div>
                        
                        <!-- Debug Info -->
                        <div class="debug-info">
                            <strong>🔍 Debug Info:</strong><br>
                            Equipos encontrados: <?php echo count($equipos_disponibles); ?><br>
                            Elementos de inspección: <?php echo count($elementos_inspeccion); ?><br>
                            <button type="button" class="btn btn-sm btn-info mt-2" onclick="mostrarDebug()">
                                Ver Detalles
                            </button>
                        </div>
                    </div>
                </div>
                
                <div class="col-lg-8">
                    <!-- Selección de Equipos -->
                    <div class="inspection-section">
                        <h4 class="mb-3">
                            <i class="fas fa-check-square me-2"></i>
                            Selecciona los Equipos a Inspeccionar
                        </h4>
                        
                        <div class="row">
                            <?php foreach ($equipos_disponibles as $equipo_item): ?>
                                <div class="col-md-6 col-lg-4">
                                    <div class="equipment-card" id="card_<?php echo $equipo_item['id']; ?>" onclick="seleccionarEquipo(<?php echo $equipo_item['id']; ?>)">
                                        <div class="form-check">
                                            <input class="form-check-input" type="checkbox" 
                                                   name="equipos_seleccionados[]" 
                                                   value="<?php echo $equipo_item['id']; ?>" 
                                                   id="equipo_<?php echo $equipo_item['id']; ?>">
                                            <label class="form-check-label w-100" for="equipo_<?php echo $equipo_item['id']; ?>">
                                                <div class="equipment-code">
                                                    <i class="fas fa-fire-extinguisher me-2"></i>
                                                    <?php echo htmlspecialchars($equipo_item['codigo_equipo']); ?>
                                                </div>
                                                <div class="equipment-location">
                                                    <i class="fas fa-map-marker-alt me-1"></i>
                                                    <?php echo htmlspecialchars($equipo_item['ubicacion']); ?>
                                                </div>
                                                <?php if ($equipo_item['numero_serie']): ?>
                                                    <small class="text-muted">
                                                        S/N: <?php echo htmlspecialchars($equipo_item['numero_serie']); ?>
                                                    </small>
                                                <?php endif; ?>
                                            </label>
                                        </div>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                        
                        <div class="text-center mt-3">
                            <button type="button" class="btn btn-success" onclick="mostrarInspecciones()">
                                <i class="fas fa-arrow-down me-2"></i>
                                Continuar con Inspección
                            </button>
                        </div>
                    </div>
                    
                    <!-- Inspección por Equipo -->
                    <div id="inspectionSections" style="display: none;">
                        <div class="alert alert-info">
                            <i class="fas fa-info-circle me-2"></i>
                            <strong>¡Perfecto!</strong> Ahora inspecciona cada equipo seleccionado individualmente.
                        </div>
                        
                        <?php foreach ($equipos_disponibles as $equipo_item): ?>
                            <div class="equipment-inspection" id="inspection_<?php echo $equipo_item['id']; ?>" style="display: none;">
                                <div class="d-flex justify-content-between align-items-center mb-3">
                                    <div>
                                        <h5 class="equipment-code mb-1">
                                            <i class="fas fa-fire-extinguisher me-2"></i>
                                            Inspeccionando: <?php echo htmlspecialchars($equipo_item['codigo_equipo']); ?>
                                        </h5>
                                        <p class="equipment-location mb-0">
                                            <i class="fas fa-map-marker-alt me-1"></i>
                                            <?php echo htmlspecialchars($equipo_item['ubicacion']); ?>
                                        </p>
                                    </div>
                                    <span class="badge bg-primary">Equipo Específico</span>
                                </div>
                                
                                <?php if (empty($elementos_inspeccion)): ?>
                                    <div class="alert alert-warning">
                                        <i class="fas fa-exclamation-triangle me-2"></i>
                                        No hay elementos de inspección configurados para este tipo.
                                    </div>
                                <?php else: ?>
                                    <?php foreach ($elementos_inspeccion as $elemento): ?>
                                        <div class="mb-4 p-3 border rounded">
                                            <div class="d-flex justify-content-between align-items-start mb-2">
                                                <strong><?php echo htmlspecialchars($elemento['descripcion']); ?></strong>
                                                <?php if ($elemento['obligatorio']): ?>
                                                    <span class="badge bg-danger">Obligatorio</span>
                                                <?php endif; ?>
                                            </div>
                                            
                                            <?php if ($elemento['tipo_respuesta'] === 'si_no_nc'): ?>
                                                <div class="response-options">
                                                    <div class="response-option response-si">
                                                        <input type="radio" 
                                                               id="si_<?php echo $equipo_item['id']; ?>_<?php echo $elemento['id']; ?>" 
                                                               name="equipo_<?php echo $equipo_item['id']; ?>_elemento_<?php echo $elemento['id']; ?>" 
                                                               value="si">
                                                        <label for="si_<?php echo $equipo_item['id']; ?>_<?php echo $elemento['id']; ?>" class="response-label">
                                                            <i class="fas fa-check"></i> SÍ
                                                        </label>
                                                    </div>
                                                    <div class="response-option response-no">
                                                        <input type="radio" 
                                                               id="no_<?php echo $equipo_item['id']; ?>_<?php echo $elemento['id']; ?>" 
                                                               name="equipo_<?php echo $equipo_item['id']; ?>_elemento_<?php echo $elemento['id']; ?>" 
                                                               value="no">
                                                        <label for="no_<?php echo $equipo_item['id']; ?>_<?php echo $elemento['id']; ?>" class="response-label">
                                                            <i class="fas fa-times"></i> NO
                                                        </label>
                                                    </div>
                                                    <div class="response-option response-nc">
                                                        <input type="radio" 
                                                               id="nc_<?php echo $equipo_item['id']; ?>_<?php echo $elemento['id']; ?>" 
                                                               name="equipo_<?php echo $equipo_item['id']; ?>_elemento_<?php echo $elemento['id']; ?>" 
                                                               value="nc">
                                                        <label for="nc_<?php echo $equipo_item['id']; ?>_<?php echo $elemento['id']; ?>" class="response-label">
                                                            <i class="fas fa-minus"></i> N/C
                                                        </label>
                                                    </div>
                                                </div>
                                            <?php endif; ?>
                                            
                                            <div class="mt-2">
                                                <input type="text" class="form-control" 
                                                       name="equipo_<?php echo $equipo_item['id']; ?>_observaciones_<?php echo $elemento['id']; ?>" 
                                                       placeholder="Observaciones específicas para <?php echo htmlspecialchars($equipo_item['codigo_equipo']); ?>">
                                            </div>
                                        </div>
                                    <?php endforeach; ?>
                                <?php endif; ?>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>
        <?php endif; ?>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        let equiposSeleccionados = [];

        function seleccionarEquipo(equipoId) {
            const checkbox = document.getElementById('equipo_' + equipoId);
            const card = document.getElementById('card_' + equipoId);
            
            // Toggle checkbox
            checkbox.checked = !checkbox.checked;
            
            // Update visual
            if (checkbox.checked) {
                card.classList.add('selected');
                if (!equiposSeleccionados.includes(equipoId)) {
                    equiposSeleccionados.push(equipoId);
                }
            } else {
                card.classList.remove('selected');
                equiposSeleccionados = equiposSeleccionados.filter(id => id !== equipoId);
            }
            
            console.log('Equipos seleccionados:', equiposSeleccionados);
        }

        function mostrarInspecciones() {
            if (equiposSeleccionados.length === 0) {
                alert('Por favor selecciona al menos un equipo para inspeccionar.');
                return;
            }
            
            const inspectionSections = document.getElementById('inspectionSections');
            inspectionSections.style.display = 'block';
            
            // Mostrar solo las inspecciones de equipos seleccionados
            equiposSeleccionados.forEach(equipoId => {
                const section = document.getElementById('inspection_' + equipoId);
                if (section) {
                    section.style.display = 'block';
                    section.classList.add('active');
                }
            });
            
            // Scroll hacia las inspecciones
            inspectionSections.scrollIntoView({ 
                behavior: 'smooth', 
                block: 'start' 
            });
        }

        function mostrarDebug() {
            const info = `
=== DEBUG INFORMACIÓN ===
Equipos disponibles: <?php echo count($equipos_disponibles); ?>
Elementos de inspección: <?php echo count($elementos_inspeccion); ?>
Equipos seleccionados: ${equiposSeleccionados.join(', ')}

Equipos encontrados:
<?php foreach ($equipos_disponibles as $eq): ?>
- ID: <?php echo $eq['id']; ?>, Código: <?php echo $eq['codigo_equipo']; ?>
<?php endforeach; ?>

Elementos de inspección:
<?php foreach ($elementos_inspeccion as $elem): ?>
- ID: <?php echo $elem['id']; ?>, Descripción: <?php echo substr($elem['descripcion'], 0, 50); ?>...
<?php endforeach; ?>
            `;
            
            alert(info);
            console.log(info);
        }

        // Inicializar
        document.addEventListener('DOMContentLoaded', function() {
            console.log('Página cargada correctamente');
            console.log('Equipos disponibles:', <?php echo count($equipos_disponibles); ?>);
            console.log('Elementos de inspección:', <?php echo count($elementos_inspeccion); ?>);
        });
    </script>
</body>
</html>
