<?php
require_once 'config/config.php';
require_once 'models/Inspeccion.php';
require_once 'models/TipoInspeccion.php';

requireLogin();

$inspeccion = new Inspeccion();
$tipoInspeccion = new TipoInspeccion();

// Obtener filtros
$filtro_tipo = $_GET['tipo'] ?? '';
$filtro_estado = $_GET['estado'] ?? '';
$filtro_fecha_desde = $_GET['fecha_desde'] ?? '';
$filtro_fecha_hasta = $_GET['fecha_hasta'] ?? '';
$busqueda = $_GET['busqueda'] ?? '';

// Obtener todas las inspecciones
$inspecciones = $inspeccion->getAll();
$tipos_inspeccion = $tipoInspeccion->getAll();

// Aplicar filtros
if (!empty($filtro_tipo) || !empty($filtro_estado) || !empty($filtro_fecha_desde) || !empty($filtro_fecha_hasta) || !empty($busqueda)) {
    $inspecciones = array_filter($inspecciones, function($insp) use ($filtro_tipo, $filtro_estado, $filtro_fecha_desde, $filtro_fecha_hasta, $busqueda) {
        // Filtro por tipo
        if (!empty($filtro_tipo) && $insp['tipo_inspeccion_id'] != $filtro_tipo) {
            return false;
        }
        
        // Filtro por estado
        if (!empty($filtro_estado) && $insp['estado'] != $filtro_estado) {
            return false;
        }
        
        // Filtro por fecha desde
        if (!empty($filtro_fecha_desde) && $insp['fecha_inspeccion'] < $filtro_fecha_desde) {
            return false;
        }
        
        // Filtro por fecha hasta
        if (!empty($filtro_fecha_hasta) && $insp['fecha_inspeccion'] > $filtro_fecha_hasta) {
            return false;
        }
        
        // Búsqueda en inmueble o contrato
        if (!empty($busqueda)) {
            $busqueda_lower = strtolower($busqueda);
            $inmueble_lower = strtolower($insp['inmueble_nombre']);
            $contrato_lower = strtolower($insp['numero_contrato']);
            
            if (strpos($inmueble_lower, $busqueda_lower) === false && 
                strpos($contrato_lower, $busqueda_lower) === false) {
                return false;
            }
        }
        
        return true;
    });
}

// Calcular estadísticas
$total_inspecciones = count($inspecciones);
$completadas = count(array_filter($inspecciones, fn($i) => $i['estado'] === 'completada'));
$borradores = count(array_filter($inspecciones, fn($i) => $i['estado'] === 'borrador'));
$aprobadas = count(array_filter($inspecciones, fn($i) => $i['estado'] === 'aprobada'));

// Estadísticas por tipo
$stats_por_tipo = [];
foreach ($inspecciones as $insp) {
    $tipo = $insp['tipo_inspeccion_nombre'] ?? 'Sin Tipo';
    if (!isset($stats_por_tipo[$tipo])) {
        $stats_por_tipo[$tipo] = 0;
    }
    $stats_por_tipo[$tipo]++;
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Inspecciones - <?php echo APP_NAME; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        body { 
            background-color: #f8f9fa; 
            font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', sans-serif;
        }
        .navbar { 
            background: linear-gradient(135deg, #667eea 0%, #764ba2 100%); 
        }
        .card { 
            border: none; 
            border-radius: 15px; 
            box-shadow: 0 5px 15px rgba(0,0,0,0.08); 
            margin-bottom: 1.5rem;
        }
        .table-hover tbody tr:hover { 
            background-color: rgba(102, 126, 234, 0.1); 
        }
        .btn-action { 
            border-radius: 20px; 
            padding: 5px 15px; 
            font-size: 0.875rem; 
        }
        .status-badge { 
            padding: 6px 12px; 
            border-radius: 15px; 
            font-weight: 600; 
            font-size: 0.85rem; 
        }
        .tipo-badge {
            padding: 4px 8px;
            border-radius: 12px;
            font-size: 0.75rem;
            font-weight: 600;
            text-transform: uppercase;
        }
        .tipo-bombas { background: #e3f2fd; color: #1565c0; }
        .tipo-extintores { background: #ffebee; color: #c62828; }
        .tipo-rociadores { background: #e8f5e8; color: #2e7d32; }
        .tipo-alarmas { background: #fff3e0; color: #ef6c00; }
        .tipo-epp { background: #f3e5f5; color: #7b1fa2; }
        .tipo-default { background: #f5f5f5; color: #616161; }
        
        .stats-card {
            background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
            color: white;
            border-radius: 15px;
            padding: 1.5rem;
            margin-bottom: 1rem;
        }
        
        .filter-section {
            background: white;
            border-radius: 15px;
            padding: 1.5rem;
            margin-bottom: 1.5rem;
            box-shadow: 0 2px 10px rgba(0,0,0,0.05);
        }
        
        .form-control, .form-select {
            border-radius: 10px;
            border: 1px solid #e0e0e0;
            padding: 0.75rem;
        }
        
        .form-control:focus, .form-select:focus {
            border-color: #667eea;
            box-shadow: 0 0 0 0.2rem rgba(102, 126, 234, 0.25);
        }
    </style>
</head>
<body>
    <!-- Navbar -->
    <nav class="navbar navbar-expand-lg navbar-dark">
        <div class="container-fluid">
            <a class="navbar-brand" href="dashboard.php">
                <i class="fas fa-fire-extinguisher me-2"></i><?php echo APP_NAME; ?>
            </a>
            <div class="navbar-nav ms-auto">
                <a class="nav-link" href="nueva_inspeccion.php">
                    <i class="fas fa-plus me-2"></i>Nueva Inspección
                </a>
                <a class="nav-link" href="dashboard.php">
                    <i class="fas fa-arrow-left me-2"></i>Dashboard
                </a>
            </div>
        </div>
    </nav>

    <div class="container-fluid py-4">
        <!-- Estadísticas -->
        <div class="row mb-4">
            <div class="col-md-3">
                <div class="stats-card text-center">
                    <h3 class="mb-1"><?php echo $total_inspecciones; ?></h3>
                    <p class="mb-0">Total Inspecciones</p>
                </div>
            </div>
            <div class="col-md-3">
                <div class="stats-card text-center">
                    <h3 class="mb-1"><?php echo $completadas; ?></h3>
                    <p class="mb-0">Completadas</p>
                </div>
            </div>
            <div class="col-md-3">
                <div class="stats-card text-center">
                    <h3 class="mb-1"><?php echo $borradores; ?></h3>
                    <p class="mb-0">Borradores</p>
                </div>
            </div>
            <div class="col-md-3">
                <div class="stats-card text-center">
                    <h3 class="mb-1"><?php echo $aprobadas; ?></h3>
                    <p class="mb-0">Aprobadas</p>
                </div>
            </div>
        </div>

        <!-- Filtros -->
        <div class="filter-section">
            <form method="GET" class="row g-3">
                <div class="col-md-2">
                    <label class="form-label">Tipo de Inspección</label>
                    <select class="form-select" name="tipo">
                        <option value="">Todos los tipos</option>
                        <?php foreach ($tipos_inspeccion as $tipo): ?>
                            <option value="<?php echo $tipo['id']; ?>" <?php echo $filtro_tipo == $tipo['id'] ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($tipo['nombre']); ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-md-2">
                    <label class="form-label">Estado</label>
                    <select class="form-select" name="estado">
                        <option value="">Todos los estados</option>
                        <option value="borrador" <?php echo $filtro_estado == 'borrador' ? 'selected' : ''; ?>>Borrador</option>
                        <option value="completada" <?php echo $filtro_estado == 'completada' ? 'selected' : ''; ?>>Completada</option>
                        <option value="aprobada" <?php echo $filtro_estado == 'aprobada' ? 'selected' : ''; ?>>Aprobada</option>
                    </select>
                </div>
                <div class="col-md-2">
                    <label class="form-label">Fecha Desde</label>
                    <input type="date" class="form-control" name="fecha_desde" value="<?php echo $filtro_fecha_desde; ?>">
                </div>
                <div class="col-md-2">
                    <label class="form-label">Fecha Hasta</label>
                    <input type="date" class="form-control" name="fecha_hasta" value="<?php echo $filtro_fecha_hasta; ?>">
                </div>
                <div class="col-md-3">
                    <label class="form-label">Buscar</label>
                    <input type="text" class="form-control" name="busqueda" placeholder="Inmueble o contrato..." value="<?php echo htmlspecialchars($busqueda); ?>">
                </div>
                <div class="col-md-1">
                    <label class="form-label">&nbsp;</label>
                    <div class="d-flex gap-2">
                        <button type="submit" class="btn btn-primary">
                            <i class="fas fa-search"></i>
                        </button>
                        <a href="inspecciones.php" class="btn btn-outline-secondary">
                            <i class="fas fa-times"></i>
                        </a>
                    </div>
                </div>
            </form>
        </div>

        <!-- Tabla de Inspecciones -->
        <div class="row">
            <div class="col-12">
                <div class="card">
                    <div class="card-header d-flex justify-content-between align-items-center">
                        <h4 class="mb-0">
                            <i class="fas fa-clipboard-list me-2"></i>
                            Todas las Inspecciones 
                            <?php if ($total_inspecciones != count($inspeccion->getAll())): ?>
                                <small class="text-muted">(<?php echo $total_inspecciones; ?> filtradas)</small>
                            <?php endif; ?>
                        </h4>
                        <a href="nueva_inspeccion.php" class="btn btn-primary">
                            <i class="fas fa-plus me-2"></i>Nueva Inspección
                        </a>
                    </div>
                    <div class="card-body">
                        <?php if (empty($inspecciones)): ?>
                            <div class="text-center py-5">
                                <i class="fas fa-clipboard-list fa-4x text-muted mb-3"></i>
                                <h5 class="text-muted">No hay inspecciones que coincidan con los filtros</h5>
                                <p class="text-muted">Intenta cambiar los criterios de búsqueda</p>
                                <a href="inspecciones.php" class="btn btn-outline-primary me-2">
                                    <i class="fas fa-times me-2"></i>Limpiar Filtros
                                </a>
                                <a href="nueva_inspeccion.php" class="btn btn-primary">
                                    <i class="fas fa-plus me-2"></i>Nueva Inspección
                                </a>
                            </div>
                        <?php else: ?>
                            <div class="table-responsive">
                                <table class="table table-hover">
                                    <thead class="table-light">
                                        <tr>
                                            <th>ID</th>
                                            <th>Tipo</th>
                                            <th>Fecha</th>
                                            <th>Inmueble</th>
                                            <th>Inspector</th>
                                            <th>Contrato</th>
                                            <th>Estado</th>
                                            <th>Acciones</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php foreach ($inspecciones as $insp): ?>
                                        <tr>
                                            <td><strong>#<?php echo $insp['id']; ?></strong></td>
                                            <td>
                                                <?php
                                                $tipo_nombre = $insp['tipo_inspeccion_nombre'] ?? 'Sin Tipo';
                                                $tipo_class = 'tipo-default';
                                                
                                                switch(strtolower($tipo_nombre)) {
                                                    case 'bombas contra incendio':
                                                    case 'bomba contra incendio':
                                                        $tipo_class = 'tipo-bombas';
                                                        break;
                                                    case 'extintores':
                                                    case 'extintor':
                                                        $tipo_class = 'tipo-extintores';
                                                        break;
                                                    case 'rociadores':
                                                    case 'sprinklers':
                                                        $tipo_class = 'tipo-rociadores';
                                                        break;
                                                    case 'alarmas':
                                                    case 'sistema de alarmas':
                                                        $tipo_class = 'tipo-alarmas';
                                                        break;
                                                    case 'epp':
                                                    case 'equipos de protección personal':
                                                        $tipo_class = 'tipo-epp';
                                                        break;
                                                }
                                                ?>
                                                <span class="tipo-badge <?php echo $tipo_class; ?>">
                                                    <?php echo htmlspecialchars($tipo_nombre); ?>
                                                </span>
                                            </td>
                                            <td><?php echo date('d/m/Y', strtotime($insp['fecha_inspeccion'])); ?></td>
                                            <td><?php echo htmlspecialchars($insp['inmueble_nombre']); ?></td>
                                            <td><?php echo htmlspecialchars($insp['inspector_nombre']); ?></td>
                                            <td><?php echo htmlspecialchars($insp['numero_contrato']); ?></td>
                                            <td>
                                                <?php
                                                $badge_class = '';
                                                switch($insp['estado']) {
                                                    case 'borrador': $badge_class = 'bg-secondary'; break;
                                                    case 'completada': $badge_class = 'bg-success'; break;
                                                    case 'aprobada': $badge_class = 'bg-primary'; break;
                                                }
                                                ?>
                                                <span class="status-badge <?php echo $badge_class; ?>">
                                                    <?php echo ucfirst($insp['estado']); ?>
                                                </span>
                                            </td>
                                            <td>
                                                <div class="btn-group" role="group">
                                                    <a href="ver_inspeccion.php?id=<?php echo $insp['id']; ?>" 
                                                       class="btn btn-sm btn-outline-primary btn-action" 
                                                       title="Ver Inspección">
                                                        <i class="fas fa-eye"></i>
                                                    </a>
                                                    <a href="generar_pdf_simple.php?id=<?php echo $insp['id']; ?>" 
                                                       class="btn btn-sm btn-outline-danger btn-action" 
                                                       title="Generar PDF" 
                                                       target="_blank">
                                                        <i class="fas fa-file-pdf"></i>
                                                    </a>
                                                    <a href="firmar_inspeccion.php?id=<?php echo $insp['id']; ?>" 
                                                       class="btn btn-sm btn-outline-warning btn-action" 
                                                       title="Firmar Inspección">
                                                        <i class="fas fa-signature"></i>
                                                    </a>
                                                    <?php if ($insp['estado'] === 'completada' && (isAdmin() || $_SESSION['user_role'] === 'supervisor')): ?>
                                                    <a href="aprobar_inspeccion.php?id=<?php echo $insp['id']; ?>" 
                                                       class="btn btn-sm btn-outline-success btn-action" 
                                                       title="Aprobar Inspección">
                                                        <i class="fas fa-check-circle"></i>
                                                    </a>
                                                    <?php endif; ?>
                                                    <?php if ($insp['estado'] === 'borrador' || isAdmin()): ?>
                                                    <a href="editar_inspeccion.php?id=<?php echo $insp['id']; ?>" 
                                                       class="btn btn-sm btn-outline-success btn-action" 
                                                       title="Editar Inspección"
                                                       style="text-decoration: none;">
                                                        <i class="fas fa-edit"></i>
                                                    </a>
                                                    <?php endif; ?>
                                                    <a href="inspeccion_equipos_completa.php?id=<?php echo $insp['id']; ?>" 
                                                       class="btn btn-sm btn-outline-info btn-action" 
                                                       title="Inspección por Equipos">
                                                        <i class="fas fa-toolbox"></i>
                                                    </a>
                                                </div>
                                            </td>
                                        </tr>
                                        <?php endforeach; ?>
                                    </tbody>
                                </table>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>

        <!-- Estadísticas por Tipo -->
        <?php if (!empty($stats_por_tipo)): ?>
        <div class="row mt-4">
            <div class="col-12">
                <div class="card">
                    <div class="card-header">
                        <h5 class="mb-0">
                            <i class="fas fa-chart-pie me-2"></i>Inspecciones por Tipo
                        </h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <?php foreach ($stats_por_tipo as $tipo => $cantidad): ?>
                            <div class="col-md-3 mb-3">
                                <div class="text-center p-3 border rounded">
                                    <h4 class="text-primary"><?php echo $cantidad; ?></h4>
                                    <p class="mb-0 small"><?php echo htmlspecialchars($tipo); ?></p>
                                </div>
                            </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php endif; ?>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
