<?php
require_once 'config/database.php';
require_once 'config/config.php';

requireLogin();

if (!isAdmin()) {
    die("Solo administradores pueden ejecutar este script");
}

// Verificar que las clases estén disponibles
if (!class_exists('Database')) {
    die("Error: No se puede cargar la clase Database. Verifica que config/database.php existe.");
}

echo "<h2>🔧 Instalador del Sistema de Aprobación</h2>";

try {
    $database = new Database();
    $conn = $database->getConnection();
    
    // Lista de campos a agregar
    $campos = [
        'aprobador_id' => 'INT NULL',
        'fecha_aprobacion' => 'DATETIME NULL',
        'comentarios_aprobacion' => 'TEXT NULL',
        'rechazador_id' => 'INT NULL',
        'fecha_rechazo' => 'DATETIME NULL',
        'motivo_rechazo' => 'TEXT NULL'
    ];
    
    echo "<h3>📋 Verificando campos existentes:</h3>";
    
    // Verificar qué campos ya existen
    $query = "DESCRIBE inspecciones";
    $stmt = $conn->prepare($query);
    $stmt->execute();
    $existing_columns = $stmt->fetchAll(PDO::FETCH_COLUMN);
    
    $campos_agregados = 0;
    $campos_existentes = 0;
    
    foreach ($campos as $campo => $tipo) {
        if (in_array($campo, $existing_columns)) {
            echo "<p>✅ <strong>$campo</strong> - Ya existe</p>";
            $campos_existentes++;
        } else {
            echo "<p>⏳ <strong>$campo</strong> - Agregando...</p>";
            
            try {
                $alter_query = "ALTER TABLE inspecciones ADD COLUMN $campo $tipo";
                $alter_stmt = $conn->prepare($alter_query);
                $alter_stmt->execute();
                echo "<p>✅ <strong>$campo</strong> - Agregado exitosamente</p>";
                $campos_agregados++;
            } catch (Exception $e) {
                echo "<p>❌ <strong>$campo</strong> - Error: " . $e->getMessage() . "</p>";
            }
        }
    }
    
    echo "<hr>";
    echo "<h3>📊 Resumen:</h3>";
    echo "<p>✅ Campos ya existentes: $campos_existentes</p>";
    echo "<p>➕ Campos agregados: $campos_agregados</p>";
    
    if ($campos_agregados > 0 || $campos_existentes == count($campos)) {
        echo "<div style='background: #d4edda; padding: 15px; border-radius: 5px; margin: 15px 0;'>";
        echo "<h4>🎉 ¡Sistema de Aprobación Instalado!</h4>";
        echo "<p>Ahora puedes:</p>";
        echo "<ul>";
        echo "<li><a href='inspecciones.php'>Ver inspecciones completadas</a></li>";
        echo "<li><a href='aprobar_inspeccion.php?id=1'>Probar aprobación (si existe inspección)</a></li>";
        echo "<li><a href='dashboard.php'>Volver al Dashboard</a></li>";
        echo "</ul>";
        echo "</div>";
        
        // Crear índices para mejorar rendimiento
        echo "<h3>🚀 Creando índices...</h3>";
        $indices = [
            "CREATE INDEX idx_inspecciones_aprobador ON inspecciones(aprobador_id)",
            "CREATE INDEX idx_inspecciones_rechazador ON inspecciones(rechazador_id)",
            "CREATE INDEX idx_inspecciones_estado ON inspecciones(estado)"
        ];
        
        foreach ($indices as $index_query) {
            try {
                $conn->exec($index_query);
                echo "<p>✅ Índice creado</p>";
            } catch (Exception $e) {
                // Los índices pueden ya existir, no es crítico
                echo "<p>⚠️ Índice ya existe o error menor</p>";
            }
        }
    }
    
} catch (Exception $e) {
    echo "<div style='background: #f8d7da; padding: 15px; border-radius: 5px; margin: 15px 0;'>";
    echo "<h4>❌ Error en la instalación</h4>";
    echo "<p>" . $e->getMessage() . "</p>";
    echo "</div>";
}

echo "<hr>";
echo "<h3>🔗 Enlaces útiles:</h3>";
echo "<p><a href='debug_aprobacion.php'>🔍 Diagnóstico del sistema</a></p>";
echo "<p><a href='dashboard.php'>🏠 Volver al Dashboard</a></p>";
echo "<p><a href='inspecciones.php'>📋 Ver Inspecciones</a></p>";
?>
