<?php
echo "<h2>Instalador de TCPDF</h2>";

// Crear directorio vendor si no existe
if (!file_exists('vendor')) {
    mkdir('vendor', 0755, true);
    echo "<p>✅ Directorio vendor creado</p>";
}

// Descargar TCPDF usando cURL o file_get_contents
$tcpdf_url = 'https://github.com/tecnickcom/TCPDF/archive/refs/tags/6.6.2.zip';
$zip_file = 'vendor/tcpdf.zip';

echo "<p>📥 Descargando TCPDF...</p>";

// Intentar con cURL primero
if (function_exists('curl_init')) {
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $tcpdf_url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
    $data = curl_exec($ch);
    curl_close($ch);
    
    if ($data) {
        file_put_contents($zip_file, $data);
        echo "<p>✅ TCPDF descargado con cURL</p>";
    }
} else {
    // Fallback a file_get_contents
    $context = stream_context_create([
        'http' => [
            'method' => 'GET',
            'header' => 'User-Agent: Mozilla/5.0'
        ]
    ]);
    
    $data = file_get_contents($tcpdf_url, false, $context);
    if ($data) {
        file_put_contents($zip_file, $data);
        echo "<p>✅ TCPDF descargado con file_get_contents</p>";
    }
}

// Verificar si se descargó
if (!file_exists($zip_file)) {
    echo "<p>❌ Error: No se pudo descargar TCPDF</p>";
    echo "<p>💡 <strong>Solución manual:</strong></p>";
    echo "<ol>";
    echo "<li>Descarga TCPDF desde: <a href='https://tcpdf.org/'>https://tcpdf.org/</a></li>";
    echo "<li>Extrae el archivo en la carpeta <code>vendor/tcpdf/</code></li>";
    echo "<li>Asegúrate de que exista el archivo <code>vendor/tcpdf/tcpdf.php</code></li>";
    echo "</ol>";
    exit();
}

// Extraer ZIP
if (class_exists('ZipArchive')) {
    $zip = new ZipArchive;
    if ($zip->open($zip_file) === TRUE) {
        $zip->extractTo('vendor/');
        $zip->close();
        
        // Renombrar directorio
        if (file_exists('vendor/TCPDF-6.6.2')) {
            rename('vendor/TCPDF-6.6.2', 'vendor/tcpdf');
        } elseif (file_exists('vendor/TCPDF-main')) {
            rename('vendor/TCPDF-main', 'vendor/tcpdf');
        }
        
        // Eliminar ZIP
        unlink($zip_file);
        
        echo "<p>✅ TCPDF extraído correctamente</p>";
    } else {
        echo "<p>❌ Error al extraer el archivo ZIP</p>";
    }
} else {
    echo "<p>❌ ZipArchive no está disponible</p>";
    echo "<p>💡 Extrae manualmente el archivo tcpdf.zip en vendor/</p>";
}

// Verificar instalación
if (file_exists('vendor/tcpdf/tcpdf.php')) {
    echo "<p>🎉 <strong>¡TCPDF instalado correctamente!</strong></p>";
    echo "<p>Ahora puedes usar <a href='generar_pdf.php?id=1'>generar_pdf.php</a></p>";
} else {
    echo "<p>❌ La instalación no se completó correctamente</p>";
    echo "<p>💡 Usa <a href='generar_pdf_simple.php?id=1'>generar_pdf_simple.php</a> como alternativa</p>";
}

// Crear directorio de assets si no existe
if (!file_exists('assets')) {
    mkdir('assets', 0755, true);
    echo "<p>✅ Directorio assets creado</p>";
}

echo "<hr>";
echo "<h3>Opciones disponibles:</h3>";
echo "<ul>";
echo "<li><a href='generar_pdf_simple.php?id=1'>📄 PDF Simple (HTML/CSS)</a> - Funciona inmediatamente</li>";
if (file_exists('vendor/tcpdf/tcpdf.php')) {
    echo "<li><a href='generar_pdf.php?id=1'>📄 PDF Avanzado (TCPDF)</a> - Con todas las funciones</li>";
}
echo "<li><a href='inspecciones.php'>🔙 Volver a Inspecciones</a></li>";
echo "</ul>";
?>
