<?php
require_once __DIR__ . '/../config/database.php';

class SeccionInspeccion {
    private $db;
    
    public function __construct() {
        $database = new Database();
        $this->db = $database->getConnection();
    }
    
    public function getByTipo($tipo_id) {
        try {
            $query = "SELECT * FROM secciones_inspeccion WHERE tipo_inspeccion_id = ? ORDER BY orden ASC";
            $stmt = $this->db->prepare($query);
            $stmt->execute([$tipo_id]);
            return $stmt->fetchAll(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            error_log("Error en SeccionInspeccion::getByTipo: " . $e->getMessage());
            return [];
        }
    }
    
    public function getById($id) {
        try {
            $query = "SELECT * FROM secciones_inspeccion WHERE id = ?";
            $stmt = $this->db->prepare($query);
            $stmt->execute([$id]);
            return $stmt->fetch(PDO::FETCH_ASSOC);
        } catch (Exception $e) {
            error_log("Error en SeccionInspeccion::getById: " . $e->getMessage());
            return false;
        }
    }
    
    public function create($data) {
        try {
            $query = "INSERT INTO secciones_inspeccion (tipo_inspeccion_id, nombre, descripcion, orden, activo) 
                     VALUES (?, ?, ?, ?, ?)";
            $stmt = $this->db->prepare($query);
            $result = $stmt->execute([
                $data['tipo_inspeccion_id'],
                $data['nombre'],
                $data['descripcion'] ?? null,
                $data['orden'] ?? $this->getMaxOrden($data['tipo_inspeccion_id']),
                $data['activo'] ?? 1
            ]);
            
            if ($result) {
                return $this->db->lastInsertId();
            }
            return false;
        } catch (Exception $e) {
            error_log("Error en SeccionInspeccion::create: " . $e->getMessage());
            return false;
        }
    }
    
    public function update($id, $data) {
        try {
            $fields = [];
            $values = [];
            
            if (isset($data['nombre'])) {
                $fields[] = "nombre = ?";
                $values[] = $data['nombre'];
            }
            
            if (isset($data['descripcion'])) {
                $fields[] = "descripcion = ?";
                $values[] = $data['descripcion'];
            }
            
            if (isset($data['orden'])) {
                $fields[] = "orden = ?";
                $values[] = $data['orden'];
            }
            
            if (isset($data['activo'])) {
                $fields[] = "activo = ?";
                $values[] = $data['activo'];
            }
            
            if (empty($fields)) {
                return false;
            }
            
            $values[] = $id;
            $query = "UPDATE secciones_inspeccion SET " . implode(', ', $fields) . " WHERE id = ?";
            $stmt = $this->db->prepare($query);
            return $stmt->execute($values);
        } catch (Exception $e) {
            error_log("Error en SeccionInspeccion::update: " . $e->getMessage());
            return false;
        }
    }
    
    public function delete($id) {
        try {
            $this->db->beginTransaction();
            
            // Eliminar elementos de la sección
            $query = "DELETE FROM elementos_inspeccion WHERE seccion_id = ?";
            $stmt = $this->db->prepare($query);
            $stmt->execute([$id]);
            
            // Eliminar la sección
            $query = "DELETE FROM secciones_inspeccion WHERE id = ?";
            $stmt = $this->db->prepare($query);
            $result = $stmt->execute([$id]);
            
            $this->db->commit();
            return $result;
        } catch (Exception $e) {
            $this->db->rollBack();
            error_log("Error en SeccionInspeccion::delete: " . $e->getMessage());
            return false;
        }
    }
    
    private function getMaxOrden($tipo_id) {
        try {
            $query = "SELECT MAX(orden) FROM secciones_inspeccion WHERE tipo_inspeccion_id = ?";
            $stmt = $this->db->prepare($query);
            $stmt->execute([$tipo_id]);
            $max = $stmt->fetchColumn();
            return $max ? $max + 1 : 1;
        } catch (Exception $e) {
            error_log("Error en SeccionInspeccion::getMaxOrden: " . $e->getMessage());
            return 1;
        }
    }
}
?>
