<?php
require_once 'config/database.php';

class User {
    private $conn;
    private $table_name = "usuarios";

    public function __construct() {
        $database = new Database();
        $this->conn = $database->getConnection();
    }

    public function login($email, $password) {
        $query = "SELECT id, nombre, email, password, rol, foto_perfil FROM " . $this->table_name . " 
                  WHERE email = :email AND activo = 1";
        
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':email', $email);
        $stmt->execute();

        if ($stmt->rowCount() > 0) {
            $row = $stmt->fetch();
            if (password_verify($password, $row['password'])) {
                $_SESSION['user_id'] = $row['id'];
                $_SESSION['user_name'] = $row['nombre'];
                $_SESSION['user_email'] = $row['email'];
                $_SESSION['user_role'] = $row['rol'];
                $_SESSION['user_photo'] = $row['foto_perfil'];
                return true;
            }
        }
        return false;
    }

    public function create($nombre, $email, $password, $rol = 'inspector') {
        $query = "INSERT INTO " . $this->table_name . " (nombre, email, password, rol) 
                  VALUES (:nombre, :email, :password, :rol)";
        
        $stmt = $this->conn->prepare($query);
        $hashed_password = password_hash($password, PASSWORD_DEFAULT);
        
        $stmt->bindParam(':nombre', $nombre);
        $stmt->bindParam(':email', $email);
        $stmt->bindParam(':password', $hashed_password);
        $stmt->bindParam(':rol', $rol);

        return $stmt->execute();
    }

    public function getAll() {
        $query = "SELECT id, nombre, email, rol, activo, fecha_creacion FROM " . $this->table_name . " 
                  ORDER BY nombre";
        
        $stmt = $this->conn->prepare($query);
        $stmt->execute();
        
        return $stmt->fetchAll();
    }

    public function getById($id) {
        $query = "SELECT id, nombre, email, rol, activo, foto_perfil FROM " . $this->table_name . " 
                  WHERE id = :id";
        
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':id', $id);
        $stmt->execute();
        
        return $stmt->fetch();
    }

    public function update($id, $nombre, $email, $rol) {
        $query = "UPDATE " . $this->table_name . " 
                  SET nombre = :nombre, email = :email, rol = :rol 
                  WHERE id = :id";
        
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':id', $id);
        $stmt->bindParam(':nombre', $nombre);
        $stmt->bindParam(':email', $email);
        $stmt->bindParam(':rol', $rol);

        return $stmt->execute();
    }

    public function delete($id) {
        $query = "UPDATE " . $this->table_name . " SET activo = 0 WHERE id = :id";
        
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':id', $id);

        return $stmt->execute();
    }

    public function verifyCurrentPassword($user_id, $password) {
        $query = "SELECT password FROM " . $this->table_name . " WHERE id = :id";
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':id', $user_id);
        $stmt->execute();
        
        if ($stmt->rowCount() > 0) {
            $row = $stmt->fetch();
            return password_verify($password, $row['password']);
        }
        return false;
    }

    public function updateProfile($id, $nombre, $email, $nueva_password = null) {
        if ($nueva_password) {
            $query = "UPDATE " . $this->table_name . " 
                  SET nombre = :nombre, email = :email, password = :password 
                  WHERE id = :id";
            $stmt = $this->conn->prepare($query);
            $hashed_password = password_hash($nueva_password, PASSWORD_DEFAULT);
            $stmt->bindParam(':password', $hashed_password);
        } else {
            $query = "UPDATE " . $this->table_name . " 
                  SET nombre = :nombre, email = :email 
                  WHERE id = :id";
            $stmt = $this->conn->prepare($query);
        }
        
        $stmt->bindParam(':id', $id);
        $stmt->bindParam(':nombre', $nombre);
        $stmt->bindParam(':email', $email);
        
        return $stmt->execute();
    }

    public function updateProfileWithPhoto($id, $nombre, $email, $foto_perfil = null, $nueva_password = null) {
        if ($nueva_password && $foto_perfil) {
            $query = "UPDATE " . $this->table_name . " 
                  SET nombre = :nombre, email = :email, password = :password, foto_perfil = :foto_perfil 
                  WHERE id = :id";
            $stmt = $this->conn->prepare($query);
            $hashed_password = password_hash($nueva_password, PASSWORD_DEFAULT);
            $stmt->bindParam(':password', $hashed_password);
            $stmt->bindParam(':foto_perfil', $foto_perfil);
        } elseif ($nueva_password) {
            $query = "UPDATE " . $this->table_name . " 
                  SET nombre = :nombre, email = :email, password = :password 
                  WHERE id = :id";
            $stmt = $this->conn->prepare($query);
            $hashed_password = password_hash($nueva_password, PASSWORD_DEFAULT);
            $stmt->bindParam(':password', $hashed_password);
        } elseif ($foto_perfil) {
            $query = "UPDATE " . $this->table_name . " 
                  SET nombre = :nombre, email = :email, foto_perfil = :foto_perfil 
                  WHERE id = :id";
            $stmt = $this->conn->prepare($query);
            $stmt->bindParam(':foto_perfil', $foto_perfil);
        } else {
            $query = "UPDATE " . $this->table_name . " 
                  SET nombre = :nombre, email = :email 
                  WHERE id = :id";
            $stmt = $this->conn->prepare($query);
        }
        
        $stmt->bindParam(':id', $id);
        $stmt->bindParam(':nombre', $nombre);
        $stmt->bindParam(':email', $email);
        
        return $stmt->execute();
    }
}
?>
