<?php
require_once 'config/config.php';
require_once 'models/Inspeccion.php';
require_once 'models/SeguimientoProblemas.php';

requireLogin();

// Solo administradores pueden ejecutar este script
if (!isAdmin()) {
    header('Location: dashboard.php');
    exit();
}

$inspeccion = new Inspeccion();
$seguimiento = new SeguimientoProblemas();

$message = '';
$error = '';
$problemas_creados = 0;

if ($_POST && isset($_POST['procesar'])) {
    try {
        // Obtener todas las inspecciones completadas
        $inspecciones = $inspeccion->getAll();
        
        foreach ($inspecciones as $insp) {
            if ($insp['estado'] === 'completada' || $insp['estado'] === 'aprobada') {
                // Verificar si ya tiene problemas registrados
                $problemas_existentes = $seguimiento->getProblemasByInspeccion($insp['id']);
                
                if (empty($problemas_existentes)) {
                    // Crear problemas para esta inspección
                    if ($seguimiento->crearProblemasDesdeInspeccion($insp['id'])) {
                        $problemas_creados++;
                    }
                }
            }
        }
        
        $message = "Procesamiento completado. Se crearon problemas para $problemas_creados inspecciones.";
    } catch (Exception $e) {
        $error = "Error al procesar: " . $e->getMessage();
    }
}

// Obtener estadísticas actuales
$estadisticas = $seguimiento->getEstadisticas();
$inspecciones_completadas = $inspeccion->getInspeccionesCompletadas();
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Procesar Problemas - <?php echo APP_NAME; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        body { background-color: #f8f9fa; }
        .card { border: none; border-radius: 15px; box-shadow: 0 5px 15px rgba(0,0,0,0.08); }
        .stat-card { text-align: center; padding: 2rem; }
        .stat-number { font-size: 2.5rem; font-weight: 700; }
        .btn-process { background: linear-gradient(135deg, #667eea 0%, #764ba2 100%); }
    </style>
</head>
<body>
    <div class="container py-5">
        <div class="row justify-content-center">
            <div class="col-lg-8">
                <div class="card">
                    <div class="card-header bg-primary text-white">
                        <h3 class="mb-0">
                            <i class="fas fa-cogs me-2"></i>
                            Procesar Problemas de Inspecciones
                        </h3>
                    </div>
                    <div class="card-body">
                        <?php if ($message): ?>
                            <div class="alert alert-success">
                                <i class="fas fa-check-circle me-2"></i>
                                <?php echo htmlspecialchars($message); ?>
                            </div>
                        <?php endif; ?>

                        <?php if ($error): ?>
                            <div class="alert alert-danger">
                                <i class="fas fa-exclamation-circle me-2"></i>
                                <?php echo htmlspecialchars($error); ?>
                            </div>
                        <?php endif; ?>

                        <div class="row mb-4">
                            <div class="col-md-4">
                                <div class="card stat-card bg-light">
                                    <div class="stat-number text-primary"><?php echo count($inspecciones_completadas); ?></div>
                                    <div>Inspecciones Completadas</div>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="card stat-card bg-light">
                                    <div class="stat-number text-warning"><?php echo $estadisticas['total'] ?? 0; ?></div>
                                    <div>Problemas Registrados</div>
                                </div>
                            </div>
                            <div class="col-md-4">
                                <div class="card stat-card bg-light">
                                    <div class="stat-number text-danger"><?php echo $estadisticas['pendientes'] ?? 0; ?></div>
                                    <div>Problemas Pendientes</div>
                                </div>
                            </div>
                        </div>

                        <div class="alert alert-info">
                            <h5><i class="fas fa-info-circle me-2"></i>¿Qué hace este proceso?</h5>
                            <ul class="mb-0">
                                <li>Revisa todas las inspecciones completadas</li>
                                <li>Identifica respuestas "NO" como problemas</li>
                                <li>Crea registros de seguimiento para cada problema</li>
                                <li>No duplica problemas ya existentes</li>
                            </ul>
                        </div>

                        <form method="POST" class="text-center">
                            <button type="submit" name="procesar" class="btn btn-process btn-lg text-white">
                                <i class="fas fa-play me-2"></i>
                                Procesar Inspecciones Existentes
                            </button>
                        </form>

                        <div class="mt-4 text-center">
                            <a href="informes.php" class="btn btn-outline-primary me-2">
                                <i class="fas fa-chart-line me-2"></i>
                                Ver Informes
                            </a>
                            <a href="dashboard.php" class="btn btn-outline-secondary">
                                <i class="fas fa-arrow-left me-2"></i>
                                Volver al Dashboard
                            </a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
