-- Agregar campos para administración de inspecciones
ALTER TABLE tipos_inspeccion ADD COLUMN IF NOT EXISTS descripcion TEXT;
ALTER TABLE tipos_inspeccion ADD COLUMN IF NOT EXISTS activo BOOLEAN DEFAULT TRUE;

ALTER TABLE secciones_inspeccion ADD COLUMN IF NOT EXISTS descripcion TEXT;
ALTER TABLE secciones_inspeccion ADD COLUMN IF NOT EXISTS activo BOOLEAN DEFAULT TRUE;

ALTER TABLE elementos_inspeccion ADD COLUMN IF NOT EXISTS obligatorio BOOLEAN DEFAULT TRUE;
ALTER TABLE elementos_inspeccion ADD COLUMN IF NOT EXISTS activo BOOLEAN DEFAULT TRUE;
ALTER TABLE elementos_inspeccion ADD COLUMN IF NOT EXISTS tipo_respuesta ENUM('si_no_nc', 'si_no', 'texto', 'numero') DEFAULT 'si_no_nc';

-- Insertar tipos de inspección adicionales
INSERT IGNORE INTO tipos_inspeccion (id, nombre, descripcion, activo) VALUES 
(2, 'Inspección de Extintores', 'Inspección y mantenimiento de extintores portátiles', TRUE),
(3, 'Inspección de Sistemas de Rociadores', 'Inspección de sistemas automáticos de rociadores', TRUE),
(4, 'Inspección de Alarmas Contra Incendios', 'Inspección de sistemas de detección y alarma', TRUE),
(5, 'Inspección de Salidas de Emergencia', 'Inspección de rutas de evacuación y salidas', TRUE);

-- Insertar secciones para extintores
INSERT IGNORE INTO secciones_inspeccion (tipo_inspeccion_id, nombre, descripcion, orden, activo) VALUES
(2, 'Inspección Visual', 'Verificación visual del extintor', 1, TRUE),
(2, 'Etiquetas y Señalización', 'Verificación de etiquetas y señales', 2, TRUE),
(2, 'Accesibilidad', 'Verificación de acceso al extintor', 3, TRUE),
(2, 'Condición Física', 'Estado físico del extintor', 4, TRUE);

-- Insertar elementos para extintores
INSERT IGNORE INTO elementos_inspeccion (seccion_id, descripcion, orden, obligatorio, activo, tipo_respuesta) VALUES
-- Inspección Visual (seccion_id = 5, asumiendo que es la primera sección de extintores)
(5, '¿El extintor está en su ubicación designada?', 1, TRUE, TRUE, 'si_no_nc'),
(5, '¿El extintor está visible y accesible?', 2, TRUE, TRUE, 'si_no_nc'),
(5, '¿El manómetro indica presión adecuada?', 3, TRUE, TRUE, 'si_no_nc'),
(5, '¿El pasador de seguridad está presente e intacto?', 4, TRUE, TRUE, 'si_no_nc'),

-- Etiquetas y Señalización (seccion_id = 6)
(6, '¿La etiqueta de inspección está presente y actualizada?', 1, TRUE, TRUE, 'si_no_nc'),
(6, '¿Las instrucciones de uso están legibles?', 2, TRUE, TRUE, 'si_no_nc'),
(6, '¿La señalización de ubicación está presente?', 3, TRUE, TRUE, 'si_no_nc'),

-- Accesibilidad (seccion_id = 7)
(7, '¿El extintor está libre de obstrucciones?', 1, TRUE, TRUE, 'si_no_nc'),
(7, '¿La altura de montaje es correcta?', 2, TRUE, TRUE, 'si_no_nc'),
(7, '¿El soporte está en buenas condiciones?', 3, TRUE, TRUE, 'si_no_nc'),

-- Condición Física (seccion_id = 8)
(8, '¿El cilindro está libre de corrosión?', 1, TRUE, TRUE, 'si_no_nc'),
(8, '¿La manguera está en buenas condiciones?', 2, TRUE, TRUE, 'si_no_nc'),
(8, '¿La boquilla está limpia y sin obstrucciones?', 3, TRUE, TRUE, 'si_no_nc');
