-- Script simple para crear tabla equipos
-- Sin claves foráneas para evitar errores

DROP TABLE IF EXISTS equipos;

CREATE TABLE equipos (
    id INT AUTO_INCREMENT PRIMARY KEY,
    inmueble_id INT NOT NULL,
    tipo_inspeccion_id INT NOT NULL,
    codigo_equipo VARCHAR(50) NOT NULL,
    numero_serie VARCHAR(100) NULL,
    ubicacion VARCHAR(255) NOT NULL,
    descripcion TEXT NULL,
    fecha_instalacion DATE NULL,
    fecha_ultimo_mantenimiento DATE NULL,
    estado_equipo ENUM('activo', 'inactivo', 'mantenimiento', 'retirado') DEFAULT 'activo',
    observaciones TEXT NULL,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    UNIQUE KEY unique_codigo_inmueble (codigo_equipo, inmueble_id)
);

-- Agregar índices para mejorar rendimiento
ALTER TABLE equipos ADD INDEX idx_inmueble (inmueble_id);
ALTER TABLE equipos ADD INDEX idx_tipo (tipo_inspeccion_id);
ALTER TABLE equipos ADD INDEX idx_estado (estado_equipo);
ALTER TABLE equipos ADD INDEX idx_codigo (codigo_equipo);

-- Insertar datos de ejemplo
INSERT INTO equipos (inmueble_id, tipo_inspeccion_id, codigo_equipo, ubicacion, descripcion) VALUES
(1, 1, 'BOMBA-001', 'Cuarto de Máquinas Principal', 'Bomba Principal 500 GPM'),
(1, 1, 'BOMBA-002', 'Cuarto de Máquinas Secundaria', 'Bomba Secundaria 500 GPM'),
(1, 2, 'EXT-001', 'Planta Baja - Recepción', 'Extintor ABC 6kg'),
(1, 2, 'EXT-002', 'Primer Piso - Oficina A', 'Extintor ABC 6kg'),
(1, 2, 'EXT-003', 'Segundo Piso - Pasillo Norte', 'Extintor ABC 6kg');

SELECT 'Tabla equipos creada exitosamente' as resultado;
SELECT * FROM equipos;
