-- Crear tabla de equipos individuales
CREATE TABLE IF NOT EXISTS equipos (
    id INT AUTO_INCREMENT PRIMARY KEY,
    inmueble_id INT NOT NULL,
    tipo_inspeccion_id INT NOT NULL,
    codigo_equipo VARCHAR(50) NOT NULL,
    numero_serie VARCHAR(100) NULL,
    ubicacion VARCHAR(255) NOT NULL,
    descripcion TEXT NULL,
    fecha_instalacion DATE NULL,
    fecha_ultimo_mantenimiento DATE NULL,
    estado_equipo ENUM('activo', 'inactivo', 'mantenimiento', 'retirado') DEFAULT 'activo',
    observaciones TEXT NULL,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (inmueble_id) REFERENCES inmuebles(id) ON DELETE CASCADE,
    FOREIGN KEY (tipo_inspeccion_id) REFERENCES tipos_inspeccion(id) ON DELETE CASCADE,
    UNIQUE KEY unique_codigo_inmueble (codigo_equipo, inmueble_id),
    INDEX idx_inmueble_tipo (inmueble_id, tipo_inspeccion_id),
    INDEX idx_estado (estado_equipo),
    INDEX idx_codigo (codigo_equipo)
);

-- Modificar tabla respuestas_inspeccion para incluir equipo_id
ALTER TABLE respuestas_inspeccion 
ADD COLUMN equipo_id INT NULL AFTER elemento_id,
ADD FOREIGN KEY (equipo_id) REFERENCES equipos(id) ON DELETE CASCADE;

-- Crear índice para mejorar rendimiento
ALTER TABLE respuestas_inspeccion 
ADD INDEX idx_equipo (equipo_id);

-- Insertar algunos equipos de ejemplo (opcional)
INSERT INTO equipos (inmueble_id, tipo_inspeccion_id, codigo_equipo, ubicacion, descripcion, estado_equipo) 
SELECT 
    i.id as inmueble_id,
    ti.id as tipo_inspeccion_id,
    CONCAT(
        CASE 
            WHEN ti.nombre LIKE '%extintor%' THEN 'EXT'
            WHEN ti.nombre LIKE '%bomba%' THEN 'BOMBA'
            WHEN ti.nombre LIKE '%epp%' THEN 'EPP'
            ELSE 'EQP'
        END,
        '-001'
    ) as codigo_equipo,
    'Ubicación por definir' as ubicacion,
    CONCAT('Equipo de ', ti.nombre) as descripcion,
    'activo' as estado_equipo
FROM inmuebles i
CROSS JOIN tipos_inspeccion ti
WHERE i.id <= 3 AND ti.id <= 3  -- Solo crear algunos ejemplos
LIMIT 9;
