<?php
require_once 'config/config.php';
require_once 'models/Inspeccion.php';
require_once 'models/FotoInspeccion.php';

requireLogin();

$inspeccion = new Inspeccion();
$fotoInspeccion = new FotoInspeccion();

$id = $_GET['id'] ?? 0;
$inspeccion_data = $inspeccion->getById($id);
$respuestas = $inspeccion->getRespuestas($id);
$fotos = $fotoInspeccion->getFotosByInspeccion($id);

if (!$inspeccion_data) {
    header('Location: dashboard.php');
    exit();
}

// Agrupar respuestas por sección
$respuestas_por_seccion = [];
foreach ($respuestas as $respuesta) {
    $respuestas_por_seccion[$respuesta['seccion_nombre']][] = $respuesta;
}

// Agrupar fotos por elemento
$fotos_por_elemento = [];
foreach ($fotos as $foto) {
    $fotos_por_elemento[$foto['elemento_id']][] = $foto;
}

// Obtener firmas si existen
$firmas = [];
try {
    $database = new Database();
    $conn = $database->getConnection();
    $stmt = $conn->prepare("SELECT * FROM firmas_inspeccion WHERE inspeccion_id = ? ORDER BY fecha_firma");
    $stmt->execute([$id]);
    $firmas = $stmt->fetchAll();
} catch (Exception $e) {
    // Tabla de firmas no existe aún o error de conexión
    $firmas = [];
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Ver Inspección - <?php echo APP_NAME; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <style>
        :root {
            --primary: #0070f3;
            --success: #00d084;
            --warning: #f5a623;
            --danger: #e00;
            --gray-50: #fafafa;
            --gray-100: #f4f4f5;
            --gray-200: #e4e4e7;
            --gray-300: #d4d4d8;
            --gray-400: #a1a1aa;
            --gray-500: #71717a;
            --gray-600: #52525b;
            --gray-700: #3f3f46;
            --gray-800: #27272a;
            --gray-900: #18181b;
        }

        * {
            box-sizing: border-box;
        }

        body {
            font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', 'Roboto', sans-serif;
            background-color: var(--gray-50);
            color: var(--gray-900);
            line-height: 1.6;
            margin: 0;
            padding: 0;
        }

        /* Header */
        .header {
            background: white;
            border-bottom: 1px solid var(--gray-200);
            padding: 1rem 0;
            position: sticky;
            top: 0;
            z-index: 50;
            box-shadow: 0 1px 3px rgba(0,0,0,0.1);
        }

        .header-content {
            max-width: 1400px;
            margin: 0 auto;
            padding: 0 1rem;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }

        .logo {
            display: flex;
            align-items: center;
            gap: 0.75rem;
            font-weight: 600;
            font-size: 1.25rem;
            color: var(--gray-900);
            text-decoration: none;
        }

        .logo:hover {
            color: var(--primary);
        }

        .header-actions {
            display: flex;
            gap: 0.75rem;
        }

        /* Main Container */
        .main-container {
            max-width: 1400px;
            margin: 0 auto;
            padding: 2rem 1rem;
        }

        /* Cards */
        .card {
            background: white;
            border: 1px solid var(--gray-200);
            border-radius: 12px;
            box-shadow: 0 1px 3px rgba(0,0,0,0.1);
            margin-bottom: 1.5rem;
        }

        .card-header {
            padding: 1.5rem;
            border-bottom: 1px solid var(--gray-200);
            background: transparent;
        }

        .card-body {
            padding: 1.5rem;
        }

        .card-title {
            font-size: 1.25rem;
            font-weight: 600;
            color: var(--gray-900);
            margin: 0;
            display: flex;
            align-items: center;
            gap: 0.75rem;
        }

        /* Info Cards */
        .info-card {
            background: linear-gradient(135deg, var(--primary), #0051cc);
            color: white;
            border: none;
        }

        .contractor-card {
            background: linear-gradient(135deg, var(--success), #00a86b);
            color: white;
            border: none;
        }

        .info-item {
            margin-bottom: 1rem;
        }

        .info-item:last-child {
            margin-bottom: 0;
        }

        .info-label {
            font-weight: 600;
            opacity: 0.9;
            font-size: 0.875rem;
            margin-bottom: 0.25rem;
        }

        .info-value {
            font-size: 1rem;
            margin: 0;
        }

        /* Section Headers */
        .section-header {
            background: linear-gradient(135deg, var(--gray-100), var(--gray-200));
            border: 1px solid var(--gray-200);
            border-radius: 8px;
            padding: 1rem 1.5rem;
            margin-bottom: 1.5rem;
        }

        .section-title {
            font-size: 1.125rem;
            font-weight: 600;
            color: var(--gray-900);
            margin: 0;
            display: flex;
            align-items: center;
            gap: 0.75rem;
        }

        /* Response Items */
        .response-item {
            background: white;
            border: 1px solid var(--gray-200);
            border-radius: 8px;
            padding: 1.5rem;
            margin-bottom: 1rem;
            transition: all 0.2s;
        }

        .response-item:hover {
            box-shadow: 0 4px 12px rgba(0,0,0,0.1);
            transform: translateY(-2px);
        }

        .response-item:last-child {
            margin-bottom: 0;
        }

        .response-content {
            display: flex;
            justify-content: space-between;
            align-items: flex-start;
            gap: 1rem;
        }

        .response-text {
            flex: 1;
        }

        .response-description {
            font-weight: 500;
            color: var(--gray-900);
            margin: 0 0 0.5rem 0;
        }

        .response-observations {
            color: var(--gray-600);
            font-size: 0.875rem;
            margin: 0;
            display: flex;
            align-items: flex-start;
            gap: 0.5rem;
        }

        .response-badge {
            padding: 0.5rem 1rem;
            border-radius: 6px;
            font-size: 0.875rem;
            font-weight: 600;
            text-transform: uppercase;
            letter-spacing: 0.025em;
            white-space: nowrap;
        }

        .response-si {
            background: #dcfce7;
            color: #166534;
        }

        .response-no {
            background: #fee2e2;
            color: #991b1b;
        }

        .response-nc {
            background: #fef3c7;
            color: #92400e;
        }

        /* Photo Gallery */
        .photo-gallery {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(120px, 1fr));
            gap: 1rem;
            margin-top: 1rem;
        }

        .photo-item {
            position: relative;
            border-radius: 8px;
            overflow: hidden;
            box-shadow: 0 2px 8px rgba(0,0,0,0.1);
            transition: all 0.2s;
            cursor: pointer;
        }

        .photo-item:hover {
            transform: scale(1.05);
            box-shadow: 0 4px 12px rgba(0,0,0,0.2);
        }

        .photo-item img {
            width: 100%;
            height: 120px;
            object-fit: cover;
            display: block;
        }

        /* Status Badge */
        .status-badge {
            padding: 0.5rem 1rem;
            border-radius: 20px;
            font-size: 0.875rem;
            font-weight: 600;
            text-transform: uppercase;
            letter-spacing: 0.025em;
        }

        .status-borrador {
            background: var(--gray-100);
            color: var(--gray-700);
        }

        .status-completada {
            background: #dcfce7;
            color: #166534;
        }

        .status-aprobada {
            background: #dbeafe;
            color: #1d4ed8;
        }

        /* Buttons */
        .btn {
            display: inline-flex;
            align-items: center;
            gap: 0.5rem;
            padding: 0.5rem 1rem;
            border: 1px solid transparent;
            border-radius: 6px;
            font-size: 0.875rem;
            font-weight: 500;
            text-decoration: none;
            cursor: pointer;
            transition: all 0.2s;
        }

        .btn-primary {
            background: var(--primary);
            color: white;
        }

        .btn-primary:hover {
            background: #0051cc;
            color: white;
        }

        .btn-outline-primary {
            border-color: var(--primary);
            color: var(--primary);
        }

        .btn-outline-primary:hover {
            background: var(--primary);
            color: white;
        }

        .btn-outline-secondary {
            border-color: var(--gray-300);
            color: var(--gray-700);
        }

        .btn-outline-secondary:hover {
            background: var(--gray-100);
            color: var(--gray-900);
        }

        .btn-sm {
            padding: 0.375rem 0.75rem;
            font-size: 0.8125rem;
        }

        /* Comments Section */
        .comments-section {
            background: var(--gray-50);
            border: 1px solid var(--gray-200);
            border-radius: 8px;
            padding: 1.5rem;
        }

        .comments-text {
            color: var(--gray-700);
            line-height: 1.6;
            margin: 0;
            white-space: pre-wrap;
        }

        /* Modal */
        .modal-content {
            border: none;
            border-radius: 12px;
            box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1);
        }

        .modal-header {
            background: var(--gray-50);
            border-bottom: 1px solid var(--gray-200);
            border-radius: 12px 12px 0 0;
        }

        .modal-body {
            padding: 2rem;
        }

        .modal-photo {
            max-width: 100%;
            height: auto;
            border-radius: 8px;
        }

        .modal-description {
            margin-top: 1rem;
            color: var(--gray-600);
            font-style: italic;
        }

        /* Firmas */
        .firma-section {
            background: white;
            border: 1px solid var(--gray-200);
            border-radius: 8px;
            padding: 1.5rem;
            margin-bottom: 1rem;
        }

        .firma-item {
            display: flex;
            align-items: center;
            gap: 1rem;
            margin-bottom: 1rem;
        }

        .firma-item:last-child {
            margin-bottom: 0;
        }

        .firma-image {
            max-width: 200px;
            max-height: 100px;
            border: none !important;
            border-radius: 4px;
            box-shadow: none !important;
            outline: none !important;
        }

        .firma-info {
            flex: 1;
        }

        .firma-tipo {
            font-weight: 600;
            color: var(--gray-900);
        }

        .firma-nombre {
            color: var(--gray-600);
            font-size: 0.875rem;
        }

        .firma-fecha {
            color: var(--gray-500);
            font-size: 0.8125rem;
        }

        /* Responsive */
        @media (max-width: 768px) {
            .main-container {
                padding: 1rem;
            }

            .response-content {
                flex-direction: column;
                gap: 1rem;
            }

            .photo-gallery {
                grid-template-columns: repeat(auto-fill, minmax(100px, 1fr));
            }

            .header-actions {
                flex-direction: column;
                gap: 0.5rem;
            }
        }
    </style>
</head>
<body>
    <!-- Header -->
    <header class="header">
        <div class="header-content">
            <a href="dashboard.php" class="logo">
                <i class="fas fa-fire-extinguisher"></i>
                <?php echo APP_NAME; ?>
            </a>
            
            <div class="header-actions">
                <a href="inspecciones.php" class="btn btn-outline-secondary btn-sm">
                    <i class="fas fa-list"></i>
                    Ver Todas
                </a>
                <a href="generar_pdf_simple.php?id=<?php echo $id; ?>" class="btn btn-outline-primary btn-sm" target="_blank">
                    <i class="fas fa-file-pdf"></i>
                    Generar PDF
                </a>
                <?php if ($inspeccion_data['estado'] === 'borrador' || isAdmin()): ?>
                <a href="editar_inspeccion.php?id=<?php echo $id; ?>" class="btn btn-primary btn-sm">
                    <i class="fas fa-edit"></i>
                    Editar
                </a>
                <?php endif; ?>
            </div>
        </div>
    </header>

    <div class="main-container">
        <div class="row">
            <!-- Información General -->
            <div class="col-lg-4 mb-4">
                <div class="card info-card">
                    <div class="card-body">
                        <h2 class="card-title text-white">
                            <i class="fas fa-info-circle"></i>
                            Información General
                        </h2>
                        
                        <div class="info-item">
                            <div class="info-label">Inmueble</div>
                            <p class="info-value"><?php echo htmlspecialchars($inspeccion_data['inmueble_nombre']); ?></p>
                        </div>
                        
                        <div class="info-item">
                            <div class="info-label">Dirección</div>
                            <p class="info-value"><?php echo htmlspecialchars($inspeccion_data['inmueble_direccion']); ?></p>
                        </div>
                        
                        <?php if ($inspeccion_data['inmueble_telefono']): ?>
                        <div class="info-item">
                            <div class="info-label">Teléfono</div>
                            <p class="info-value"><?php echo htmlspecialchars($inspeccion_data['inmueble_telefono']); ?></p>
                        </div>
                        <?php endif; ?>
                        
                        <div class="info-item">
                            <div class="info-label">Inspector</div>
                            <p class="info-value"><?php echo htmlspecialchars($inspeccion_data['inspector_nombre']); ?></p>
                        </div>
                        
                        <div class="info-item">
                            <div class="info-label">Fecha de Inspección</div>
                            <p class="info-value"><?php echo date('d/m/Y', strtotime($inspeccion_data['fecha_inspeccion'])); ?></p>
                        </div>
                        
                        <?php if ($inspeccion_data['numero_contrato']): ?>
                        <div class="info-item">
                            <div class="info-label">N.º de Contrato</div>
                            <p class="info-value"><?php echo htmlspecialchars($inspeccion_data['numero_contrato']); ?></p>
                        </div>
                        <?php endif; ?>
                        
                        <div class="info-item">
                            <div class="info-label">Estado</div>
                            <span class="status-badge status-<?php echo $inspeccion_data['estado']; ?>">
                                <?php echo ucfirst($inspeccion_data['estado']); ?>
                            </span>
                        </div>
                    </div>
                </div>

                <?php if ($inspeccion_data['contratista_nombre']): ?>
                <div class="card contractor-card">
                    <div class="card-body">
                        <h2 class="card-title text-white">
                            <i class="fas fa-user-tie"></i>
                            Contratista
                        </h2>
                        
                        <div class="info-item">
                            <div class="info-label">Nombre</div>
                            <p class="info-value"><?php echo htmlspecialchars($inspeccion_data['contratista_nombre']); ?></p>
                        </div>
                        
                        <?php if ($inspeccion_data['contratista_direccion']): ?>
                        <div class="info-item">
                            <div class="info-label">Dirección</div>
                            <p class="info-value"><?php echo htmlspecialchars($inspeccion_data['contratista_direccion']); ?></p>
                        </div>
                        <?php endif; ?>
                        
                        <?php if ($inspeccion_data['contratista_licencia']): ?>
                        <div class="info-item">
                            <div class="info-label">Licencia</div>
                            <p class="info-value"><?php echo htmlspecialchars($inspeccion_data['contratista_licencia']); ?></p>
                        </div>
                        <?php endif; ?>
                    </div>
                </div>
                <?php endif; ?>
            </div>

            <!-- Resultados de Inspección -->
            <div class="col-lg-8">
                <div class="card">
                    <div class="card-header">
                        <h1 class="card-title">
                            <i class="fas fa-clipboard-check"></i>
                            Resultados de Inspección - <?php echo htmlspecialchars($inspeccion_data['tipo_inspeccion_nombre'] ?? 'Sin Tipo'); ?>
                        </h1>
                    </div>
                    <div class="card-body">
                        <?php if (empty($respuestas_por_seccion)): ?>
                            <div class="text-center py-5">
                                <i class="fas fa-clipboard-list fa-4x text-muted mb-3"></i>
                                <h3 class="text-muted">No hay respuestas registradas</h3>
                                <p class="text-muted">Esta inspección aún no tiene respuestas</p>
                                <?php if ($inspeccion_data['estado'] === 'borrador'): ?>
                                <a href="editar_inspeccion.php?id=<?php echo $id; ?>" class="btn btn-primary">
                                    <i class="fas fa-edit"></i>
                                    Completar Inspección
                                </a>
                                <?php endif; ?>
                            </div>
                        <?php else: ?>
                            <?php foreach ($respuestas_por_seccion as $seccion_nombre => $respuestas_seccion): ?>
                                <div class="section-header">
                                    <h2 class="section-title">
                                        <i class="fas fa-cogs"></i>
                                        <?php echo htmlspecialchars($seccion_nombre); ?>
                                    </h2>
                                </div>

                                <?php foreach ($respuestas_seccion as $respuesta): ?>
                                    <div class="response-item">
                                        <div class="response-content">
                                            <div class="response-text">
                                                <p class="response-description">
                                                    <?php echo htmlspecialchars($respuesta['elemento_descripcion']); ?>
                                                </p>
                                                
                                                <!-- Mostrar información del equipo si existe -->
                                                <?php if (!empty($respuesta['codigo_equipo'])): ?>
                                                    <div class="mb-2">
                                                        <span class="badge bg-info">
                                                            <i class="fas fa-cog"></i> 
                                                            Equipo: <?php echo htmlspecialchars($respuesta['codigo_equipo']); ?>
                                                            <?php if (!empty($respuesta['numero_serie'])): ?>
                                                                | S/N: <?php echo htmlspecialchars($respuesta['numero_serie']); ?>
                                                            <?php endif; ?>
                                                            <?php if (!empty($respuesta['equipo_ubicacion'])): ?>
                                                                | Ubicación: <?php echo htmlspecialchars($respuesta['equipo_ubicacion']); ?>
                                                            <?php endif; ?>
                                                        </span>
                                                    </div>
                                                <?php endif; ?>
                                                
                                                <?php if ($respuesta['observaciones']): ?>
                                                    <p class="response-observations">
                                                        <i class="fas fa-comment"></i>
                                                        <strong>Observaciones:</strong> <?php echo htmlspecialchars($respuesta['observaciones']); ?>
                                                    </p>
                                                <?php endif; ?>
                                            </div>
                                            <div>
                                                <?php
                                                $response_class = '';
                                                $response_icon = '';
                                                $response_text = '';
                                                
                                                switch($respuesta['respuesta']) {
                                                    case 'si':
                                                        $response_class = 'response-si';
                                                        $response_icon = 'fas fa-check';
                                                        $response_text = 'SÍ';
                                                        break;
                                                    case 'no':
                                                        $response_class = 'response-no';
                                                        $response_icon = 'fas fa-times';
                                                        $response_text = 'NO';
                                                        break;
                                                    case 'nc':
                                                        $response_class = 'response-nc';
                                                        $response_icon = 'fas fa-minus';
                                                        $response_text = 'N/C';
                                                        break;
                                                }
                                                ?>
                                                <span class="response-badge <?php echo $response_class; ?>">
                                                    <i class="<?php echo $response_icon; ?>"></i> <?php echo $response_text; ?>
                                                </span>
                                            </div>
                                        </div>

                                        <!-- Mostrar fotos si existen -->
                                        <?php if (isset($fotos_por_elemento[$respuesta['elemento_id']])): ?>
                                            <div class="photo-gallery">
                                                <?php foreach ($fotos_por_elemento[$respuesta['elemento_id']] as $foto): ?>
                                                    <div class="photo-item" onclick="showPhoto('<?php echo htmlspecialchars($foto['ruta_archivo']); ?>', '<?php echo htmlspecialchars($foto['descripcion']); ?>')">
                                                        <img src="<?php echo htmlspecialchars($foto['ruta_archivo']); ?>" 
                                                             alt="Foto de inspección">
                                                    </div>
                                                <?php endforeach; ?>
                                            </div>
                                        <?php endif; ?>
                                    </div>
                                <?php endforeach; ?>
                            <?php endforeach; ?>
                        <?php endif; ?>

                        <!-- Comentarios -->
                        <?php if ($inspeccion_data['comentarios']): ?>
                            <div class="section-header">
                                <h2 class="section-title">
                                    <i class="fas fa-comments"></i>
                                    Comentarios Adicionales
                                </h2>
                            </div>
                            <div class="comments-section">
                                <p class="comments-text"><?php echo htmlspecialchars($inspeccion_data['comentarios']); ?></p>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>

                <!-- Firmas Digitales -->
                <?php if (!empty($firmas)): ?>
                <div class="card">
                    <div class="card-header">
                        <h2 class="card-title">
                            <i class="fas fa-signature"></i>
                            Firmas Digitales
                        </h2>
                    </div>
                    <div class="card-body">
                        <?php foreach ($firmas as $firma): ?>
                            <div class="firma-item">
                                <img src="<?php echo htmlspecialchars($firma['firma_base64']); ?>" 
                                     alt="Firma" class="firma-image">
                                <div class="firma-info">
                                    <div class="firma-tipo"><?php echo ucfirst($firma['tipo_firma']); ?></div>
                                    <div class="firma-nombre"><?php echo htmlspecialchars($firma['nombre_firmante']); ?></div>
                                    <div class="firma-fecha"><?php echo date('d/m/Y H:i', strtotime($firma['fecha_firma'])); ?></div>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
                <?php endif; ?>

                <!-- Acciones -->
                <div class="card">
                    <div class="card-body text-center">
                        <a href="inspecciones.php" class="btn btn-outline-secondary me-2">
                            <i class="fas fa-arrow-left"></i>
                            Volver al Listado
                        </a>
                        <?php if ($inspeccion_data['estado'] === 'borrador' || isAdmin()): ?>
                        <a href="editar_inspeccion.php?id=<?php echo $id; ?>" class="btn btn-primary me-2">
                            <i class="fas fa-edit"></i>
                            Editar Inspección
                        </a>
                        <?php endif; ?>
                        <a href="firmar_inspeccion.php?id=<?php echo $id; ?>" class="btn btn-warning me-2">
                            <i class="fas fa-signature"></i>
                            Firmar Inspección
                        </a>
                        <a href="generar_pdf_simple.php?id=<?php echo $id; ?>" class="btn btn-outline-primary" target="_blank">
                            <i class="fas fa-file-pdf"></i>
                            Generar PDF
                        </a>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Modal para ver fotos -->
    <div class="modal fade" id="photoModal" tabindex="-1">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">
                        <i class="fas fa-camera me-2"></i>
                        Fotografía de Inspección
                    </h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body text-center">
                    <img id="modalPhoto" src="/placeholder.svg" alt="Foto de inspección" class="modal-photo">
                    <p id="modalPhotoDescription" class="modal-description"></p>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        function showPhoto(src, description) {
            document.getElementById('modalPhoto').src = src;
            document.getElementById('modalPhotoDescription').textContent = description || 'Sin descripción';
            new bootstrap.Modal(document.getElementById('photoModal')).show();
        }
    </script>
</body>
</html>
