<?php
require_once 'config/config.php';
require_once 'models/Equipo.php';

// Verificar conexión a base de datos
try {
    $database = new Database();
    $db = $database->getConnection();
    echo "✅ Conexión a base de datos: OK<br>";
} catch (Exception $e) {
    echo "❌ Error de conexión: " . $e->getMessage() . "<br>";
    exit();
}

// Verificar si existe la tabla equipos
try {
    $query = "SHOW TABLES LIKE 'equipos'";
    $stmt = $db->prepare($query);
    $stmt->execute();
    $result = $stmt->fetch();
    
    if ($result) {
        echo "✅ Tabla 'equipos' existe<br>";
        
        // Verificar estructura de la tabla
        $query = "DESCRIBE equipos";
        $stmt = $db->prepare($query);
        $stmt->execute();
        $columns = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        echo "<h3>Estructura de la tabla equipos:</h3>";
        echo "<table border='1' style='border-collapse: collapse;'>";
        echo "<tr><th>Campo</th><th>Tipo</th><th>Nulo</th><th>Clave</th><th>Default</th></tr>";
        foreach ($columns as $col) {
            echo "<tr>";
            echo "<td>" . $col['Field'] . "</td>";
            echo "<td>" . $col['Type'] . "</td>";
            echo "<td>" . $col['Null'] . "</td>";
            echo "<td>" . $col['Key'] . "</td>";
            echo "<td>" . $col['Default'] . "</td>";
            echo "</tr>";
        }
        echo "</table><br>";
        
    } else {
        echo "❌ Tabla 'equipos' NO existe. Ejecuta el script SQL primero.<br>";
    }
} catch (Exception $e) {
    echo "❌ Error verificando tabla: " . $e->getMessage() . "<br>";
}

// Verificar modelo Equipo
try {
    $equipo = new Equipo();
    echo "✅ Modelo Equipo: OK<br>";
    
    // Probar método de estadísticas
    $stats = $equipo->getEstadisticas();
    echo "✅ Método getEstadisticas: OK<br>";
    
} catch (Exception $e) {
    echo "❌ Error en modelo Equipo: " . $e->getMessage() . "<br>";
}

// Verificar datos de prueba
try {
    $query = "SELECT COUNT(*) as total FROM equipos";
    $stmt = $db->prepare($query);
    $stmt->execute();
    $count = $stmt->fetch(PDO::FETCH_ASSOC);
    
    echo "📊 Total de equipos en base de datos: " . $count['total'] . "<br>";
    
    if ($count['total'] > 0) {
        $query = "SELECT * FROM equipos LIMIT 3";
        $stmt = $db->prepare($query);
        $stmt->execute();
        $equipos = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        echo "<h3>Equipos de ejemplo:</h3>";
        foreach ($equipos as $eq) {
            echo "- ID: {$eq['id']}, Código: {$eq['codigo_equipo']}, Ubicación: {$eq['ubicacion']}<br>";
        }
    }
    
} catch (Exception $e) {
    echo "❌ Error consultando equipos: " . $e->getMessage() . "<br>";
}

echo "<br><a href='dashboard.php'>← Volver al Dashboard</a>";
echo " | <a href='gestionar_equipos.php'>Gestionar Equipos →</a>";
?>
