<?php
require_once 'config/database.php';

echo "<h2>🔍 Verificación de Tablas del Sistema</h2>";

try {
    $database = new Database();
    $db = $database->getConnection();
    echo "<p>✅ <strong>Conexión a base de datos:</strong> OK</p>";
    
    // Lista de tablas que deberían existir
    $tablas_requeridas = [
        'usuarios',
        'inmuebles', 
        'tipos_inspeccion',
        'elementos_inspeccion',
        'inspecciones',
        'respuestas_inspeccion',
        'fotos_inspeccion',
        'equipos'
    ];
    
    echo "<h3>📋 Estado de las Tablas:</h3>";
    echo "<table border='1' style='border-collapse: collapse; width: 100%;'>";
    echo "<tr style='background: #f0f0f0;'><th>Tabla</th><th>Estado</th><th>Registros</th><th>Acción</th></tr>";
    
    foreach ($tablas_requeridas as $tabla) {
        echo "<tr>";
        echo "<td><strong>$tabla</strong></td>";
        
        // Verificar si la tabla existe
        $query = "SHOW TABLES LIKE '$tabla'";
        $stmt = $db->prepare($query);
        $stmt->execute();
        $existe = $stmt->fetch();
        
        if ($existe) {
            echo "<td style='color: green;'>✅ Existe</td>";
            
            // Contar registros
            try {
                $query = "SELECT COUNT(*) as total FROM $tabla";
                $stmt = $db->prepare($query);
                $stmt->execute();
                $count = $stmt->fetch(PDO::FETCH_ASSOC);
                echo "<td>" . $count['total'] . " registros</td>";
                echo "<td>-</td>";
            } catch (Exception $e) {
                echo "<td>Error al contar</td>";
                echo "<td>Verificar estructura</td>";
            }
        } else {
            echo "<td style='color: red;'>❌ No existe</td>";
            echo "<td>-</td>";
            echo "<td style='color: red;'>Crear tabla</td>";
        }
        
        echo "</tr>";
    }
    echo "</table>";
    
    // Verificar estructura específica de equipos si existe
    $query = "SHOW TABLES LIKE 'equipos'";
    $stmt = $db->prepare($query);
    $stmt->execute();
    $equipos_existe = $stmt->fetch();
    
    if ($equipos_existe) {
        echo "<h3>🔧 Estructura de la tabla 'equipos':</h3>";
        $query = "DESCRIBE equipos";
        $stmt = $db->prepare($query);
        $stmt->execute();
        $columns = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        echo "<table border='1' style='border-collapse: collapse; width: 100%;'>";
        echo "<tr style='background: #f0f0f0;'><th>Campo</th><th>Tipo</th><th>Nulo</th><th>Clave</th><th>Default</th></tr>";
        foreach ($columns as $col) {
            echo "<tr>";
            echo "<td>" . $col['Field'] . "</td>";
            echo "<td>" . $col['Type'] . "</td>";
            echo "<td>" . ($col['Null'] == 'YES' ? 'Sí' : 'No') . "</td>";
            echo "<td>" . $col['Key'] . "</td>";
            echo "<td>" . ($col['Default'] ?? 'NULL') . "</td>";
            echo "</tr>";
        }
        echo "</table>";
        
        // Mostrar algunos equipos de ejemplo
        echo "<h3>📦 Equipos registrados (primeros 5):</h3>";
        $query = "SELECT * FROM equipos LIMIT 5";
        $stmt = $db->prepare($query);
        $stmt->execute();
        $equipos = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        if (count($equipos) > 0) {
            echo "<table border='1' style='border-collapse: collapse; width: 100%;'>";
            echo "<tr style='background: #f0f0f0;'><th>ID</th><th>Código</th><th>Ubicación</th><th>Estado</th></tr>";
            foreach ($equipos as $eq) {
                echo "<tr>";
                echo "<td>" . $eq['id'] . "</td>";
                echo "<td><strong>" . htmlspecialchars($eq['codigo_equipo']) . "</strong></td>";
                echo "<td>" . htmlspecialchars($eq['ubicacion']) . "</td>";
                echo "<td>" . ucfirst($eq['estado_equipo']) . "</td>";
                echo "</tr>";
            }
            echo "</table>";
        } else {
            echo "<p>No hay equipos registrados aún.</p>";
        }
    }
    
} catch (Exception $e) {
    echo "<p>❌ <strong>Error:</strong> " . $e->getMessage() . "</p>";
}

echo "<br><hr>";
echo "<h3>🚀 Próximos pasos:</h3>";
echo "<ol>";
echo "<li>Si la tabla 'equipos' no existe, ejecuta: <code>scripts/10_create_equipos_simple.sql</code></li>";
echo "<li>Ve al <a href='dashboard.php'>Dashboard</a> y usa 'Gestionar Equipos'</li>";
echo "<li>Registra tus primeros equipos</li>";
echo "</ol>";

echo "<p><a href='dashboard.php'>← Volver al Dashboard</a> | ";
echo "<a href='gestionar_equipos.php'>Gestionar Equipos →</a></p>";
?>
